/*---------------------------------------------------------------------------+
|
|     MODULE NAME:   FeCommon.C
|
|
|         $Author:   Dennis_Bareis  $
|                    Andreas Buchinger  2009-2024
|       $Revision:   1.0  $
|           $Date:   28 Sep 1996 15:08:28  $
|        $Logfile:   C:/PROJECTS/OS2/PVCS.IT/PMPRINTF/FECOMMON.C_V  $
|
|     DESCRIPTION:
|
+---------------------------------------------------------------------------*/

/*------ Make constant string definition more efficient & protect them! -----*/
#pragma  strings(readonly)

/*------ Include required Header files --------------------------------------*/
#define  INCL_DOS
#define  INCL_DOSPROCESS
#define  INCL_DOSERRORS
#define  INCL_NOPMAPI
#define  INCL_LONGLONG  // 20090705 AB

#include <os2.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include "FeCommon.H"



/*--- Command line switch table ---------------------------------------------*/
typedef struct STR_TO_ID
	{
	char  * String;
	long    Id;
	}              STR_TO_ID;
static STR_TO_ID SwitchTable[] =
{
	/*--- The following commands do NOT require colons ----------------------*/
#define OPTION_NEWCOLON               1L
#define OPTION_NEW_Q_NAME             2L
#define LOG_OPTION_ONLY_BASE          1000
#define OPTION_NEW_LOG_NAME           (LOG_OPTION_ONLY_BASE + 0L)
#define OPTION_NEW_LOG_TIME_FMT       (LOG_OPTION_ONLY_BASE + 1L)


	/*--- Table of valid commands -------------------------------------------*/
	{ "NewQueueName"               ,OPTION_NEW_Q_NAME},
	{ "LogFileName"                ,OPTION_NEW_LOG_NAME},
	{ "LogTimeFmt"                 ,OPTION_NEW_LOG_TIME_FMT},
	{ NULL                         ,0}
};




/*===========================================================================*/
static long _Optlink GetIdFromString(STR_TO_ID * Table, char  * String)
/*===========================================================================*/
	{
	/*--- Search whole table -------------------------------------------------*/
	while ( Table->String != NULL )
		{
		/*--- Does this entry match? -----------------------------------------*/
		if ( stricmp(String, Table->String) == 0 )
			{
			/*--- Found it! --------------------------------------------------*/
			return(Table->Id);
			}

		/*--- Point to next entry --------------------------------------------*/
		Table++;
		}

	/*--- Info not found -----------------------------------------------------*/
	return(0);
	}



#ifdef   CommentBlock  /* (Sunday 23/06/1996, 16:50:06, by Dennis_Bareis) */
**+--------------------------------------------------------------------------
**|/*===========================================================================*/
**|static LONG _Optlink GetValidValueOrDie(   char  * IntegerString,
**|                                           LONG    LowestValidValue,
**|                                           LONG    HighestValidValue,
**|                                           char  * SwitchBeingProcessed
**|                                       )
**|/*===========================================================================*/
**|{
**|    char    * Ptr;
**|    LONG      LongValue;
**|
**|		 /*--- Get the value -----------------------------------------------------*/
**|    LongValue = strtol(IntegerString, &Ptr, 0);
**|    if ( *Ptr != '\0' )
**|        SyntaxError(__LINE__, "Invalid integer value of \"%s\" on switch \"%s\"", IntegerString, SwitchBeingProcessed);
**|
**|		 /*--- Now check the value for range -------------------------------------*/
**|    if ( LongValue < LowestValidValue )
**|        SyntaxError(__LINE__, "The value on the \"%s\" switch can't be less than %ld", SwitchBeingProcessed, LowestValidValue);
**|    if ( LongValue > HighestValidValue )
**|        SyntaxError(__LINE__, "The value on the \"%s\" switch can't be greater than %ld", SwitchBeingProcessed, HighestValidValue);
**|
**|		 /*--- return the value to the caller ------------------------------------*/
**|    return(LongValue);
**|}
**+--------------------------------------------------------------------------
#endif                 /* (Sunday 23/06/1996, 16:50:06, by Dennis_Bareis) */



/*===========================================================================*/
void _Optlink ProcessParameterDieOnFailure(    CMDLINEOPTIONS    * CmdLineOptions,
																							 LOGCMDLINEOPTIONS * LogCmdLineOptions,
																							 _SyntaxErrorFunc    _SyntaxError,
																							 char              * Switch
																					)
/*===========================================================================*/
	{
	static char    ColonChar        = ':';
	ULONG   Option;
	char  * ColonPtr;
	char    Argument[300+1];

	/*--- Make sure a valid switch was specified -----------------------------*/
	if ( (Switch[0] != '/') && (Switch[0] != '-') )
		_SyntaxError(__LINE__, "Must specify \"/\" or \"-\" on all switches");

	/*--- Make a copy of the argument (so we can modify etc as required ------*/
	strcpy(Argument, &Switch[1]);			//Drop leading switch character in copy

	/*--- Look for a colon (seperates command from any parameters ------------*/
	if ( (ColonPtr=strchr(Argument, ColonChar)) != NULL )
		*ColonPtr++ = '\0';				 //Terminate argument and point to parameters

	/*--- Make sure the option is understood ---------------------------------*/
	if ( *Argument == '\0' )
		Option = OPTION_NEWCOLON;
	else
		Option = GetIdFromString(SwitchTable, Argument);
	if ( Option == 0 )
		{
		/*--- The option is unknown ------------------------------------------*/
		_SyntaxError(__LINE__, "Unknown option of \"%c%s\"", Switch[0], Argument);
		}

	/*--- Some options are only valid for the logging program! ---------------*/
	if ( (LogCmdLineOptions == NULL) && (Option >= LOG_OPTION_ONLY_BASE) )
		_SyntaxError(__LINE__, "The \"%c%s\" switch is only valid for PMPFLOG.EXE", Switch[0], Argument);

	/*--- Some commands ALWAYS require the ':' check for these ---------------*/
	//  if  (Option >= CMD_REQUIRES_COLON)
	{
		if ( ColonPtr == NULL )
			_SyntaxError(__LINE__, "No '%c' supplied (a value must be specified)", ColonChar);
	}

	/*--- Process the option -------------------------------------------------*/
	switch ( Option )
		{
		/*+++++++++++++++++++++++++++++++++++*/
		case OPTION_NEWCOLON:
			/*+++++++++++++++++++++++++++++++++++*/
			{
				ColonChar = *ColonPtr++;
				if ( *ColonPtr != '\0' )
					_SyntaxError(__LINE__, "Expected a single character to be specified on the \"%s\" switch", Argument);
				ColonPtr = NULL;
				break;
			}
			/*+++++++++++++++++++++++++++++++++++*/
		case OPTION_NEW_Q_NAME:
			/*+++++++++++++++++++++++++++++++++++*/
			{
				CmdLineOptions->ShortQueueName = strdup(ColonPtr);
				ColonPtr = NULL;
				break;
			}
			/*+++++++++++++++++++++++++++++++++++*/
		case OPTION_NEW_LOG_NAME:
			/*+++++++++++++++++++++++++++++++++++*/
			{
				LogCmdLineOptions->FullLogFileName = strdup(ColonPtr);
				ColonPtr = NULL;
				break;
			}
			/*+++++++++++++++++++++++++++++++++++*/
		case OPTION_NEW_LOG_TIME_FMT:
			/*+++++++++++++++++++++++++++++++++++*/
			{
				LogCmdLineOptions->LogTimeFormat = strdup(ColonPtr);
				ColonPtr = NULL;
				break;
			}
			/*+++++++++++++++++++++++++++++++++++*/
		default:
			/*+++++++++++++++++++++++++++++++++++*/
			_SyntaxError(__LINE__, "%s(%d) BUG: Unknown option of %d", __FILE__, __LINE__, Option);
			break;
		}

	/*--- Check for unused parameters on command -----------------------------*/
	if ( ColonPtr != NULL )
		_SyntaxError(__LINE__, "Unused parameters on command \"%s\"", Switch);
	}





/*===========================================================================*/
void _Optlink CreatePmprintfQueue( char                 * QueueName,
																	 _QueueMsgHandlerFunc   _QueueMsgHandler,
																	 _ErrorFunc             _ErrorHandler
																 )
/*===========================================================================*/
	{
	HQUEUE        QueueHandle;
	ULONG         DosRc;
	REQUESTDATA   Request;
	ULONG         MessageSize;
	char        * ReceivedPtr;
	BYTE          MessagePriority;
	time_t        MsgTimeStamp;
	ULONG         NumberMessages;

	/*--- Create the Queue ---------------------------------------------------*/
	DosRc = DosCreateQueue(&QueueHandle, QUE_FIFO, QueueName);
	if ( DosRc != 0 )
		{
		/*--- See if its because of duplicated Queue -------------------------*/
		if ( DosRc == ERROR_QUE_DUPLICATE )
			_ErrorHandler(__LINE__, "Queue \"%s\" is already being used...", QueueName);
		else
			_ErrorHandler(__LINE__, "Can't create queue \"%s\" (DosRc=%lu)", QueueName, DosRc);
		}

	/*--- Wait for queued messages -------------------------------------------*/
	for ( ;; )
		{
		/*--- Read the Queue -------------------------------------------------*/
		DosRc=DosReadQueue(QueueHandle, &Request, &MessageSize, (void **)&ReceivedPtr, 0, 0, &MessagePriority, 0);
		if ( DosRc != 0 )
			_ErrorHandler(__LINE__, "Read error on queue \"%s\" (DosRc=%lu)", QueueName, DosRc);

		/*--- See how many messages are on the queue -------------------------*/
		NumberMessages = 0;
		DosQueryQueue(QueueHandle, &NumberMessages);

		/*--- Now pass info the function which will process it ---------------*/
		_QueueMsgHandler(ReceivedPtr, (time_t)Request.ulData, ((long)MessageSize < 0), NumberMessages);
		}
	}

