/*---------------------------------------------------------------------------+
|
|
|     MODULE NAME:   FeCommon.H
|
|
|         $Author:   Dennis_Bareis  $
|                    Andreas Buchinger  2009-2024
|       $Revision:   1.0  $
|           $Date:   28 Sep 1996 15:08:52  $
|        $Logfile:   C:/PROJECTS/OS2/PVCS.IT/PMPRINTF/FECOMMON.H_V  $
|
|     DESCRIPTION:   Common Header file for definitions that are used by
|                    bothe the pM & Logging FRONT END programs.
+---------------------------------------------------------------------------*/
#ifndef  HEADER_FECOMMON_H
	#define  HEADER_FECOMMON_H

/*--- General Definitions ---------------------------------------------------*/
	//#define PGM_VERSION_DB            "AB 96.280 "__DATE__" "__TIME__
//	#define PGM_VERSION               "2.80.beta1 (AB "  PGM_VERSION_DB  ")"	// this line will be processed by make_bldlevel.cmd
// ----------------------------------------> don't do this, does not work use at max like next line
// ---------------------------------> "2.80.b2 (AB " PGM_VERSION_DB ")"	
// 20240101 seems there is a max. ClassName/WinTitle limit of 53 chars. Otherwise PmPrintf.exe (main in PFEXE.c) can not WinCreateStdWindow
	#define PGM_VERSION               "2.80 (AB 96.280 "__DATE__" "__TIME__")"	// this line will be processed by make_bldlevel.cmd
	#define PMPRINTF_CLASS_NAME       "PmPrintf.EXE v"PGM_VERSION
	#define MAX_LINE_LENGTH           2000
	#define DEFAULT_LOG_NAME          "C:\\PMPRINTF.LOG"

/*--- Profile definitions ---------------------------------------------------*/
	#define APP_PROFILE_NAME              "PMprintf32-DB$"
	#define KEY_WINDOW_PARMS_AND_POSN     "PresParmsAndPosn"
	#define KEY_NAME_OF_LOG_FILE          "NameOfLogFile"
	#define KEY_ADD_TIME_TO_LOGGED_LINES  "AddTimeToLoggedLines"
	#define KEY_TIME_IN_LISTBOX           "TimeInListbox"
	#define KEY_LOGGING_RECEIVED_LINES    "LoggingReceivedLines"
	#define KEY_SAVE_PRESPARMS            "Save"     KEY_WINDOW_PARMS_AND_POSN
	#define KEY_RESTORE_PRESPARMS         "Restore"  KEY_WINDOW_PARMS_AND_POSN
	#define KEY_CASE_SENSITIVE_SEARCHES   "CaseSensitiveSearches"
	#define KEY_TIME_FORMAT               "TimeFormat"
	#define KEY_SEARCH_STRING             "SearchString"
	#define KEY_MAX_LINES_IN_LISTBOX      "MaxLinesInListBox"

/*------ The following macros check for bits being set or reset -------------*/
	#define  AllBitsAreSet(field,mask)   ( ( (field) & (mask) ) == (mask) )
	#define  BitsAreSet(   field,mask)   ( (field) & (mask) )
	#define  NoBitsAreSet( field,mask)   ( ( (field) & (mask) ) == 0 )

/*------ The following macros set/reset bits in a field ---------------------*/
	#define  SetBits(   field,mask)      field = (field | (mask) )
	#define  ResetBits( field,mask)      field = (field & (~(mask)) )
	#define  ToggleBits(field,mask)      field = (field ^ (mask) )

/*--- Default time format ---------------------------------------------------*/
	#define DEFAULT_TIME_FMT "%a"    /* Day of Week (Fri)  */  \
                         " "                               \
                         "%H"    /* Time-HH            */  \
                         ":"                               \
                         "%M"    /* Time-MM            */  \
                         ":"                               \
                         "%S"    /* Time-SS            */  \
                         "%p"    /* Time AM or PM      */  \
                         "> "    /* seperate from what follows */

/*--- Define COMMON Command Line options ------------------------------------*/
typedef struct CMDLINEOPTIONS
	{
	char  * ShortQueueName;
	#define DEFAULT_PRINTF_QUEUE_NAME "PRINTF32"
	}              CMDLINEOPTIONS;
	#define    DEFAULT_CMDLINEOPTIONS {DEFAULT_PRINTF_QUEUE_NAME}
typedef struct LOGCMDLINEOPTIONS							 //Used only by logging Front End!
	{
	char  * LogTimeFormat;
	char  * FullLogFileName;
	}              LOGCMDLINEOPTIONS;
	#define    DEFAULT_LOGCMDLINEOPTIONS {DEFAULT_TIME_FMT, DEFAULT_LOG_NAME}


/*--- Definitions for "FeCommon.C" ------------------------------------------*/
typedef void (_System _SyntaxErrorFunc)(int ExitRc, char  * Format, ...);
void _Optlink ProcessParameterDieOnFailure(    CMDLINEOPTIONS    * CmdLineOptions,
																							 LOGCMDLINEOPTIONS * LogCmdLineOptions,
																							 _SyntaxErrorFunc    _SyntaxError,
																							 char              * Switch
																					);
typedef void (_System _ErrorFunc)(int ExitRc, char  * Format, ...);
typedef void (_Optlink _QueueMsgHandlerFunc)(char  * Msg, time_t MsgTimeStamp, BOOL Beep, ULONG NumberMsgsInQueue);
void _Optlink CreatePmprintfQueue( char                 * QueueName,
																	 _QueueMsgHandlerFunc   _QueueMsgHandler,
																	 _ErrorFunc             _ErrorHandler
																 );




#endif



