/*---------------------------------------------------------------------------+
|
|     (C)opyright Dennis Bareis and Andreas Buchinger
|     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
|
|     MODULE NAME:   WPSDEBUG.C
|
|
|         $Author:   Dennis_Bareis  $
|                    Andreas Buchinger  2009-2024
|       $Revision:   1.0  $
|           $Date:   17 Aug 1996 13:39:08  $
|        $Logfile:   C:/PROJECTS/OS2/PVCS.IT/PMPRINTF/WPSDEBUG.C_V  $
|
|     DESCRIPTION:   This module contains code which will allow you to debug
|                    your SOM/WPS classes.  It is best if this code be
|                    placed into a DLL, otherwise you may find 2 or more
|                    of your classes competing for output (and probably
|                    ending up with strange output...
+---------------------------------------------------------------------------*/

/*------ Make constant string definition more efficient & protect them! -----*/
#pragma  strings(readonly)

/*------ Include required Header files --------------------------------------*/
#define  INCL_DOSNMPIPES
#define  INCL_LONGLONG  // 20090705 AB

#include <os2.H>
#include <SOM.H>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "WPSDEBUG.H"
#include "PMPRINTF.H"


/*--- Global variables for the character buffer -----------------------------*/
static CHAR  Buffer[WPSDEBUG_MAX_LINE_CHARS+1];
static ULONG BytesInBuffer = 0;
static BOOL  RemovePath    = TRUE;



/*===========================================================================*/
static void _Optlink FlushBufferToNamedPipe(void)
/*===========================================================================*/						
	{
	/*--- Output what we have and reset buffer ------------------------------*/
	PmPrintfString(Buffer);

	/*--- There are now no bytes buffered -----------------------------------*/
	BytesInBuffer = 0 ;
	}




/*===========================================================================*/
static int _System AnzCharOutRoutine(char Character)	 //Replaces SOM routine
/*===========================================================================*/						
	{
	/*--- Is this a newline -------------------------------------------------*/
	if ( Character != '\n' )
		{
		/*--- Not end of line yet so store character ------------------------*/
		Buffer[BytesInBuffer++] = Character;

		/*--- Buffer full, if so flush --------------------------------------*/
		if ( BytesInBuffer == sizeof(Buffer)-1 )		//Allow space for null byte
			{
			Buffer[BytesInBuffer]   = '\0';
			FlushBufferToNamedPipe();
			}
		}
	else
		{
		/*--- We need to output a CR & LF -----------------------------------*/
		Buffer[BytesInBuffer]   = '\0';
		FlushBufferToNamedPipe();
		}
	return(1);
	}





/*===========================================================================*/
void _Optlink I_WpsDebugOutputModuleIdHeader(char  *SourceModule, int LineNumber, char  *Function)
/*===========================================================================*/						
	{
	char  * ModuleName;

	/*--- See if the source name has a path, remove if so -------------------*/
	ModuleName = SourceModule;
	if ( RemovePath )
		{
		if ( (ModuleName=strrchr(ModuleName, '\\')) != NULL )
			ModuleName++;												//Point past '\'
		else
			ModuleName = SourceModule;
		}

	/*--- Display the header ------------------------------------------------*/
	if ( Function == NULL )
		somPrintf("%s,%4d : ", ModuleName, LineNumber);
	else
		somPrintf("%s,%4d, %.50s() : ", ModuleName, LineNumber, Function);
	}



/*===========================================================================*/
void _Optlink I_WpsDebugInstall(int TraceLevel, PMPRINTF_MODE PmprintfMode, void **AddressOfSOMOutCharRoutine, int * AddressOfSOM_TraceLevel)
/*                                                                           */
/*  This routine turns tracing on, to make it easier to call its expected    */
/*  only to be called via the WpsDebugInstall() macro.                       */
/*                                                                           */
/*  The addresses of the SOM stuff are passed to allow this code to be       */
/*  kept seperate from the WPS stuff (for example in a seperate DLL).        */
/*===========================================================================*/						
	{

	/*--- Set the PMPRINTF debugging mode -----------------------------------*/
	PmPrintfModeSet(PmprintfMode);

	/*--- Update SOM global variables ---------------------------------------*/
	if ( (*AddressOfSOMOutCharRoutine != (void *)AnzCharOutRoutine)
			 || (*AddressOfSOM_TraceLevel    != TraceLevel)
		 )
		{
		char    Message[200];

		// 20090307 AB, dummy declaration to include floating point library
		float fTest = 1.3423;
		printf("float test %f", fTest * fTest / 1.00232);

		/*--- This is the first time so store value away & beep -------------*/
		*AddressOfSOMOutCharRoutine = (void *)AnzCharOutRoutine;

		/*--- Set the requested trace level ---------------------------------*/
		*AddressOfSOM_TraceLevel    = TraceLevel;

		/*--- Tell the user whats happening ---------------------------------*/
		DosBeep(1000,80);
		sprintf(Message, "**** WpsDebug state modified (TraceLevel=%u, PmprintfMode=0x%08X) ****", TraceLevel, PmprintfMode);
		PmPrintfString("");											//Blank line
		PmPrintfString(Message);

		/*--- Output version info -------------------------------------------*/
		strcpy(Message, "**** WPSDEBUG.C version "    WPSDEBUG_VERSION
					 ", Last modified at "          __TIMESTAMP__
					 ", compiled at "               __DATE__ " " __TIME__
					 " ****"
					);
		PmPrintfString(Message);
		PmPrintfDisplayInterfaceVersionInfo();
		}
	}




/*==========================================================================*/
void _Optlink WpsDebugPmMsgBox( char  * Title,
																char  * Format,
																...
															)
/*==========================================================================*/						
	{
	va_list   Args;
	char    * Message;
#define LARGEST_POPUPMSG_IN_CHARS 2000

	/*--- Allocate memory for the message -----------------------------------*/
	if ( (Message=malloc(LARGEST_POPUPMSG_IN_CHARS+1)) == NULL )
		{
		/*--- Output error message to PMRINTF.EXE ---------------------------*/
		WpsDebugF(( "Malloc failed, can't display Title=\"%s\"\a\n"
								,Title == NULL ? "{NULL}" : Title
							));
		return;
		}

	/*-- Format the message ------------------------------------------------*/
	va_start(Args, Format);
	vsprintf(Message, Format, Args);
	va_end(Args);

	/*-- Display the message -----------------------------------------------*/
	WinMessageBox(  HWND_DESKTOP,
									NULLHANDLE,
									Message,
									Title,
									0,
									MB_INFORMATION | MB_SYSTEMMODAL | MB_MOVEABLE
							 );

	/*--- Free the allocated memory -----------------------------------------*/
	free(Message);
	}

