.*----------------------------------------------------------------------------
.*
.*     MODULE NAME:   IPFGEN.IPF
.*
.*         $Author:   Dennis_Bareis  $
.*                    Andreas Buchinger  2009-2024
.*       $Revision:   1.8  $
.*           $Date:   09 Aug 1996 15:55:22  $
.*        $Logfile:   Q:/PVCSDATA/SUPPORT/SUPPORT/IPFGEN.IPV  $
.*
.*     DESCRIPTION:   This This file is included in all .IPF files
.*                    and provides common macros & definitions.
.*
.*----------------------------------------------------------------------------




.********************************************************************************************************************************
.*
.* The following macros are used to define the start and end of EXAMPLES.
.*
.* Your examples can either be formatted (contain .br, &amp. etc) or not,
.* you must know what you want. Unformatted is the "default" as it covers
.* most cases.
.*
.* EXAMPLE 1:
.*              :Example.
.*              The following example contains many lines with & and :
.*              characters which will be converted to &amp. etc
.*              automatically.
.*
.*              .im  XYZ.H
.*              :eExample.
.*
.* EXAMPLE 2:
.*              :ExampleFormatted.
.*              This line contains formatting in brackets (&amp), this
.*              would be incorrectly formatted if ":Example." were to be
.*              used.  This type of "example" would be used if you want
.*              hypertext links etc..
.*
.*              :eExampleFormatted.
.*
.********************************************************************************************************************************
.dm Example on
.*
.**** Start Example (small compact font) **************************
:xmp.
:font facename='Courier' size=8x8.
$StartTextChanges                        ;;Start conversions specified in "IPFXMP.IPF".
.dm off
.dm eExample on
$StopTextChanges                         ;;Stop  conversions specified in "IPFXMP.IPF".
:font facename=default size=0x0.
:exmp.
.**** End Example *************************************************
.*
.dm off
.dm ExampleFormatted on
.*
.**** Start Example (small compact font) IPF tagging allowed ******
:xmp.
:font facename='Courier' size=8x8.
<$KeepBlankLines>                        ;;Don't remove blank lines from the example.
.dm off
.dm eExampleFormatted on
<$RemoveBlankLines>                     ;;Remove any blank lines that are found in the source (example completed).
:font facename=default size=0x0.
:exmp.
.**** End Example *************************************************
.*
.dm off
.dm ExampleLarge on
.*
.**** Start Example (normal example font) *************************
:xmp.
$StartTextChanges                        ;;Start conversions specified in "IPFXMP.IPF".
.dm off
.dm eExampleLarge on
$StopTextChanges                         ;;Stop  conversions specified in "IPFXMP.IPF".
:exmp.
.**** End Example *************************************************
.*
.dm off
.dm ExampleLargeFormatted on
.*
.**** Start Example (normal example font) IPF tagging allowed *****
:xmp.
<$KeepBlankLines>                        ;;Don't remove blank lines from the example.
.dm off
.dm eExampleLargeFormatted on
<$RemoveBlankLines>                     ;;Remove any blank lines that are found in the source (example completed).
:exmp.
.**** End Example *************************************************
.*
.dm off




.********************************************************************************************************************************
.**** HERE FOR COMPATABILITY, PLEASE STOP USING THESE DEFINITIONS! **************************************************************
.********************************************************************************************************************************
.*
.* This macro is used to imbed files which may have "&" etc but they are
.* not IPF formatting.  A "C" header is an example.
.*
.* Currently a method to stop the system from incorrectly interpreting
.* the formatting is not known.  IT MAY BE IN FUTURE.
.*
.* INPUT-
.*              p1 = File Name
.*
.* EXAMPLE-
.*              :IncludeTextFile p1='EXAMPLE.H'.
.*
.********************************************************************************************************************************
.**      CommentBlock  /* (Wednesday the 16/06/1993, 08:01:33) */
.**+--------------------------------------------------------------------------
.**|.dm IncludeTextFile on
.**|.im &p1.
.**|.dm off
.**+--------------------------------------------------------------------------
.**                    /* (Wednesday the 16/06/1993, 08:01:33) */
.nameit symbol=RealExample text='$StartTextChanges'
.nameit symbol=eRealExample text='$StopTextChanges'



.********************************************************************************************************************************
.*
.* This macro is used to increase or decrease the margin by the
.* standard amount.
.*
.* EXAMPLE-
.*              :SetMargin p1=35'.
.*              :Indent.
.*              :Outdent.
.*
.********************************************************************************************************************************
.dm MarginSet on
<$Margin=&p1.>
:lm margin=<$Margin?>.
.dm off
.dm Indent on
<$Margin+>
<$Margin+>
<$Margin+>
<$Margin+>
:lm margin=<$Margin?>.
.dm off
.dm Outdent on
<$Margin->
<$Margin->
<$Margin->
<$Margin->
:lm margin=<$Margin?>.
.dm off



.********************************************************************************************************************************
.*
.* This macro is used to specify a heading level.  Initially its set to '1'
.* and the ':HeaderUp|:HeaderDown' macros adjust it.
.*
.* INPUT-
.*              p1 = Heading level (top most heading is '1'.
.*
.* EXAMPLE-
.*              :HeadingLevel p1='1'.
.*
.********************************************************************************************************************************
.dm HeadingLevel on
<$Level=&p1.>
.dm off



.********************************************************************************************************************************
.*
.* These macros adjust the a heading level up or down 1.
.*
.* EXAMPLE-
.*              :HeadingLevelDown.
.*
.********************************************************************************************************************************
.dm HeadingLevelUp on
<$Level->
.dm off
.dm HeadingLevelDown on
<$Level+>
.dm off



.********************************************************************************************************************************
.*
.* This macro is used to create a heading.  The heading is on the same "level" as the previous one.
.*
.* INPUT-
.*              p1 = Id used as destination for hypertext links.
.*              p2 = Text wanted in Contents.
.*
.* EXAMPLE-
.*              :Heading p1='CssIntroduction' p2='CSS API Introduction'.
.*              :HeadingNoId p1='CSS API Introduction'.
.*
.********************************************************************************************************************************
.dm Heading on
.*
.*** New Heading at Current Level *************************
:h<$Level?> id=&p1..&p2.
.dm off
.dm HeadingNoId on
.*
.*** New Heading at Current Level *************************
:h<$Level?>.&p1.
.dm off



.********************************************************************************************************************************
.*
.* This macro is used to create a heading.  The heading is DOWN one "level" from the previous one.
.*
.* INPUT-
.*              p1 = Id used as destination for hypertext links.
.*              p2 = Text wanted in Contents.
.*
.* EXAMPLE-
.*              :HeadingDown p1='CssIntroduction' p2='CSS API Introduction'.
.*              :HeadingNoIdDown p1='CSS API Introduction'.
.*
.********************************************************************************************************************************
.dm HeadingDown on
.*
.*** New Heading > ***************************************
<$Level+>
:h<$Level?> id=&p1..&p2.
.dm off
.dm HeadingNoIdDown on
.*
.*** New Heading > ***************************************
<$Level+>
:h<$Level?>.&p1.
.dm off



.********************************************************************************************************************************
.*
.* This macro is used to create a heading.  The heading is UP one "level" from the previous one.
.*
.* INPUT-
.*              p1 = Id used as destination for hypertext links.
.*              p2 = Text wanted in Contents.
.*
.* EXAMPLE-
.*              :HeadingUp p1='CssIntroduction' p2='CSS API Introduction'.
.*              :HeadingNoIdUp p1='CSS API Introduction'.
.*
.********************************************************************************************************************************
.dm HeadingUp on
.*** New Heading < ***************************************
<$Level->
:h<$Level?> id=&p1..&p2.
.dm off
.dm HeadingNoIdUp on
.*** New Heading < ***************************************
<$Level->
:h<$Level?>.&p1.
.dm off




.********************************************************************************************************************************
.*
.* This macro is used to create a title.
.*
.* INPUT-
.*              p1 = Title wanted
.*
.* EXAMPLE-
.*              :BigTitle p1='PROTOTYPE'.
.*
.********************************************************************************************************************************
.dm BigTitle on
:p.:color fc=neutral.:font facename=Helv size=24x24.:hp7.&p1.:color fc=default.:font facename=default size=0x0.:ehp7.
.dm off




.********************************************************************************************************************************
.*
.* This macro is used to create a hypertext link.  No quotes automatically
.* surround this.
.*
.* The text displayed for the displayed link is the same as the ID it links to.
.*
.* INPUT-
.*              p1 = ID to link to.
.*
.* EXAMPLE-
.*              :LinkTo p1='OtherStuff'.
.*
.********************************************************************************************************************************
.dm LinkTo on
:link reftype=hd refid=&p1..&p1.:elink.
.dm off



.********************************************************************************************************************************
.*
.* This macro is used to create a hypertext link.  No quotes automatically surround this.
.*
.* In this case the text to be displayed is also specified.
.*
.* INPUT-
.*              p1 = ID to link to.
.*              p2 = Text to be displayed.
.*
.* EXAMPLE-
.*              :LinkToText p1='OtherStuff' p2='Other Stuff'.
.*
.********************************************************************************************************************************
.dm LinkToText on
:link reftype=hd refid=&p1..&p2.:elink.
.dm off


.********************************************************************************************************************************
.*
.* This macro is used to refer to a function else where.
.*
.* The function is put into quotes and ends with "()".
.*
.* Note that this macro assumes that the function name is used as the
.* id= in a heading.
.*
.* INPUT-
.*              p1 = Function Name
.*
.* EXAMPLE-
.*              :h2 id=UtlUnderDevelopmentSystem.UtlUnderDevelopmentSystem()
.*              ..
.*              ..
.*              :h2 id=OtherFunction.OtherFunction()
.*              ..
.*              call to :LinkFunction p1='UtlUnderDevelopmentSystem'.
.*
.********************************************************************************************************************************
.dm LinkToFunction on
":link reftype=hd refid=&p1..&p1.():elink."
.dm off
.*
.***************** Don't use the following (trying to set up convention) *****************************
.dm LinkFunction on
":link reftype=hd refid=&p1..&p1.():elink."
.dm off




.********************************************************************************************************************************
.*
.* This macro is used to create a hypertext link.  No quotes automatically
.* surround this.
.*
.* The name of the EXTERNAL DATABASE is specified.
.*
.* The text displayed for the displayed link is the same as the ID it links to.
.* The ID of the link is the text as displayed when looking at
.* the database.
.*
.*
.* INPUT-
.*        CommentBlock  /* (Monday the 31/01/1994, 10:12:07) */
.* +--------------------------------------------------------------------------
.* |.*              p1 = ID to link to.
.* +--------------------------------------------------------------------------
.*                      /* (Monday the 31/01/1994, 10:12:07) */
.*              p1 = ID to link to (text).
.*              p2 = DataBase name (with extension)
.*
.* EXAMPLE-
.*        CommentBlock  /* (Monday the 31/01/1994, 10:22:25) */
.* +--------------------------------------------------------------------------
.* |.*              :LinkToDb p1='OtherStuff' p2='UTLAPI.INF'.
.* +--------------------------------------------------------------------------
.*                      /* (Monday the 31/01/1994, 10:22:25) */
.*              :LinkToDb p1='A Heading' p2='UTLAPI.INF'.
.*
.********************************************************************************************************************************
.*        CommentBlock  /* (Monday the 31/01/1994, 10:07:12) */
.* +--------------------------------------------------------------------------
.* |:link reftype=hd database='&p2.' refid=&p1..&p1.:elink.
.* +--------------------------------------------------------------------------
.*                      /* (Monday the 31/01/1994, 10:07:12) */
.dm LinkToDb on
:link reftype=launch object='view.exe' data='&p2. "&p1."'.&p1.:elink.
.dm off


.********************************************************************************************************************************
.*
.* This macro is used to create a hypertext link.  No quotes automatically
.* surround this.
.*
.* The name of the EXTERNAL DATABASE is specified.  The ID of the wanted section is unknown
.* the link is created through the title of the section.
.*
.* INPUT-
.*              p1 = ID to link to (title).
.*              p2 = Text to display.
.*              p3 = DataBase name
.*
.* EXAMPLE-
.*              :LinkToDbTitle p1='41H - Set Bit Rate' p2='ASYNC_SETBAUDRATE' p3='PROGREF20'.
.*
.*
.********************************************************************************************************************************
.dm LinkToDbTitle on
:link reftype=launch object='view.exe' data='&p3. "&p1."'.&p2.:elink.
.dm off




.********************************************************************************************************************************
.*
.* This macro is used to create a hypertext link.  No quotes automatically
.* surround the text displayed.
.*
.* The name of the EXTERNAL DATABASE is specified.
.*
.* The database required is loaded with no initial position supplied.
.* It would normally come up displaying the CONTENTS window.
.*
.* INPUT-
.*              p1 = Text to display.
.*              p2 = DataBase name (with extension)
.*
.* EXAMPLE-
.*              :LinkLoadDbText p1='text to display' p2='UTLAPI.INF'.
.*
.********************************************************************************************************************************
.dm LinkLoadDbText on
:link reftype=launch object='view.exe' data='&p2.'.&p1.:elink.
.dm off



.********************************************************************************************************************************
.*
.* These macros use the highlight phase command to produce different highlighting.
.*
.* INPUT-
.*              p1 = Text
.*
.* EXAMPLE-
.*              :Magenta p1='This text is highlighed'.
.*
.********************************************************************************************************************************
.dm Italic on
:hp1.&p1.:ehp1.
.dm off
.*
.dm Bold on
:hp2.&p1.:ehp2.
.dm off
.*
.dm BoldItalic on
:hp3.&p1.:ehp3.
.dm off
.*
.dm BoldUnderline on
:hp7.&p1.:ehp7.
.dm off
.*
.dm Red on
:hp8.&p1.:ehp8.
.dm off
.*
.dm Magenta on
:hp9.&p1.:ehp9.
.dm off
.*
.dm LightBlue on
:DarkGreen.
.dm off
.*;hp4.&p1.;color fc=default.(DB$-Can't use due to warp bug with their change of colors)
.*
.dm DarkGreen on
:color fc=darkgreen.&p1.:color fc=default.
.dm off



.********************************************************************************************************************************
.*
.* These macros use the highlight phase command to produce different highlighting.
.*
.* INPUT-
.*              p1 = Text
.*
.* EXAMPLE-
.*              &OrdList.
.*              :li. Item 1
.*              :li. Item 2
.*              &eOrdList.
.*
.********************************************************************************************************************************
.*        CommentBlock  /* (Monday the 31/01/1994, 09:12:26) */
.* +--------------------------------------------------------------------------
.* |.nameit symbol=OrdList text=':lm margin=5.:ol.'
.* |.nameit symbol=eOrdList text=':eol.:lm margin=1.'
.* +--------------------------------------------------------------------------
.*                      /* (Monday the 31/01/1994, 09:12:26) */
.dm OrdList on
.*
.*** Start Numbered List *********************************
:Indent.
:ol.
.dm off
.dm eOrdList on
:eol.
:Outdent.
.*** End   Numbered List *********************************
.*
.dm off
.dm OrdListCompact on
.*
.*** Start Numbered List *********************************
:Indent.
:ol compact.
.dm off
.dm eOrdListCompact on
:eol.
:Outdent.
.*** End   Numbered List *********************************
.*
.dm off
.dm UnNumberedList on
.*
.*** Start UnNumbered List *********************************
:Indent.
:ul.
.dm off
.dm eUnNumberedList on
:eul.
:Outdent.
.*** End   UnNumbered List *********************************
.*
.dm off
.dm UnNumberedListCompact on
.*
.*** Start UnNumbered List *********************************
:Indent.
:ul compact.
.dm off
.dm eUnNumberedListCompact on
:eul.
:Outdent.
.*** End   UnNumbered List *********************************
.*
.dm off
