#*---------------------------------------------------------------------------+
#
#     MODULE NAME:   PRJVAC30.MAK
#
#         $Author:   Dennis_Bareis  $
#                    Andreas Buchinger  2009-2024
#       $Revision:   1.11  $
#           $Date:   04 Feb 1998 13:51:58  $
#        $Logfile:   Q:/PVCSDATA/SUPPORT/support/prjvac30.mav  $
#
#     DESCRIPTION:   Include file for all PRJ make files that use Visual Age C++ (V3.0)
#                    compiler and tools (or one compatible with it).
#
#     UNUSUAL EXTENSIONS:
#     ~~~~~~~~~~~~~~~~~~
#                    .DIL   - DLL Import library (used in place of .LIB).
#                    .OB    - An object (.OBJ) compiled with "/Gd+" and NOT "/Gd-".  When linked "/NOI" is
#                             automatically used.
#                    ._xx   - In the output directory are "temporary" files used in LIBs/LINKs and kept for debugging.
#
#
#     SOME IMPORTANT DETAILS
#     ~~~~~~~~~~~~~~~~~~~~~~
#          (a)  TO USE ANZ DLLs or C runtime DLLs
#               ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#               You must include only ".OB" files (not ".obj"). And if using
#               general ANZ routines UTL, MSG, LOG etc then use ".DIL" when
#               linking.
#
#          (b)  TO USE ANZ LIBs or C static link
#               ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#               You must include only ".OBJ" files (not ".ob"). And if using
#               general ANZ routines UTL, MSG, LOG etc then use ".LIB" when
#               linking.
#
#          Note it is possible that you can override the need for the above
#          if /NOI is used when linking and default library searching is disabled
#          as well.  UNTESTED as yet!
#
#---------------------------------------------------------------------------*/

#### Sundry definitions #####################################################
MakVersion               = 97.318
#MakName                  = $(INPUTFILE)
MakName                  = PRJVAC30.MAK
OUTPUT_DIRECTORY         = .\OUT
OutputDirectory          = $(OUTPUT_DIRECTORY)
TempObjPathForLibrarian  = $(OutputDirectory)\LIB.TMP
CppTemplateDirectory     = $(OutputDirectory)\T
PrjSupportDir            = $(PRJSUPPORTDIR)
PrjInclude               = $(PRJINCLUDE)
PrjLib                   = $(PRJLIB)
ICCFLG_MULTI_THREAD      = -Gm+
ICCFLG_ALLOW_SLASHBY2    = -Ss
ICCFLG_COMPILE_AS_C      = -Tdc
ICCFLG_COMPILE_AS_CPP    = -Tdp

#############################################################################
#### Load definitions which can be overriden by user ########################
#############################################################################
.INCLUDE $(PrjSupportDir)\PRJVAC30.INC



.PATH.c     = .
.PATH.cpp   = .;$(CppTemplateDirectory)
.PATH.h     = .;$(OUTPUT_DIRECTORY);$(PrjInclude);$(INCLUDE)
.PATH.hpp   = .;$(OUTPUT_DIRECTORY);$(PrjInclude);$(INCLUDE)
.PATH.txt   = .
.PATH.err   = .
.PATH.hlp   = .
.PATH.ipf   = .;$(PrjSupportDir)
.PATH.iph   = .;$(PrjSupportDir)
.PATH.xmp   = .;$(PrjSupportDir)
.PATH.mih   = .;$(PrjSupportDir)
.PATH.inf   = $(OUTPUT_DIRECTORY)
.PATH.def   = .;$(OUTPUT_DIRECTORY)
.PATH.ih    = $(OUTPUT_DIRECTORY)
.PATH.hlp   = $(OUTPUT_DIRECTORY)
.PATH.obj   = $(OUTPUT_DIRECTORY)
.PATH.ob    = $(OUTPUT_DIRECTORY)
.PATH.res   = $(OUTPUT_DIRECTORY)
.PATH.exe   = $(OUTPUT_DIRECTORY)
.PATH.dll   = $(OUTPUT_DIRECTORY)
.PATH.sym   = $(OUTPUT_DIRECTORY)
.PATH.lib   = $(OUTPUT_DIRECTORY);$(PrjLib);$(LIB)
.PATH.dil   = $(OUTPUT_DIRECTORY);$(PrjLib);$(LIB)
.PATH.itf   = $(OUTPUT_DIRECTORY)
.PATH.msg   = $(OUTPUT_DIRECTORY)
.PATH.map   = $(OUTPUT_DIRECTORY)

#### An RC file may need to be generated when using Visual Builder (from .RCX") ###
.PATH.rc    = $(OUTPUT_DIRECTORY);.

#### These extensions are used INSTEAD of visual Builder's ".O" files #######
.PATH.os    = $(OUTPUT_DIRECTORY)
.PATH.od    = $(OUTPUT_DIRECTORY)

#### Other Weird Visual Builder Entensions ##################################
.PATH.app   = .
.PATH.cpv   = .
.PATH.hpv   = .
.PATH.rcx   = .

#### We make .HTM from .IT & .IH files ######################################
.PATH.htm  = $(OUTPUT_DIRECTORY);.
.PATH.it   = .;
.PATH.ih   = .;$(PrjSupportDir)



#############################################################################
### Need $(PrjSupportDir) in the following "PATH.lst" so as the handle the
### imbed of "SUEPROJ.LST" in the PMANUAL project.
#############################################################################
.PATH.lst   = $(OUTPUT_DIRECTORY);.;$(PrjSupportDir)


#############################################################################

#------ SET UP THE DEFAULT RULE ---------------------------------------------
TOTAL:                               \
        CLEANUP_AFTER_MAKE           \
        EXPORT_BEFORE_PASS_1         \
        MAKE_IN_PASS1                \
        EXPORT_BEFORE_PASS_2         \
        MAKE_IN_PASS2                \
        EXPORT_AFTER_MAKE


#------ SET UP RULES FOR A PERSON ON A SINGLE PROJECT WANTING TO EXPORT -----
EXPORT:
        EXPORT_BEFORE_PASS_1         \
        EXPORT_BEFORE_PASS_2         \
        EXPORT_AFTER_MAKE



#------ SET UP LISTS FOR THINGS TO MAKE IN EACH PASS ------------------------
MAKE_IN_PASS1:  $(MAKE_IN_PASS1_LIST)
MAKE_IN_PASS2:  $(MAKE_IN_PASS2_LIST)

#----- SET these up in case PRJEXPRT.MAK is not used ------------------------
EXPORT_BEFORE_PASS_1 ::
        %do  AddBlankLines
        @echo BEFORE_PASS_1
EXPORT_BEFORE_PASS_2 ::
        %do  AddBlankLines
        @echo BEFORE_PASS_2
EXPORT_AFTER_MAKE    ::
        %do  AddBlankLines
        @echo AFTER_MAKE

############################################################################
.PROLOG:
############################################################################
        @echo.
        @echo ****
        @echo **** Version $(MakVersion) of $(MakName) starting
        @echo ****
        @echo.




###      CommentBlock  /* (Wednesday the 17/03/1993, 10:17:12) */
###+--------------------------------------------------------------------------
###|#------ SET UP RULES FOR EXPORTING TO SUPPORT (initial) ---------------------
###|EXPORT_BEFORE_PASS_1 ::
###|%if %defined(TO_SUPPORT)
###|%foreach file in $(FILES_TO_SUPPORT_LIST)
###|EXPORT_BEFORE_PASS_1 :: $(TO_SUPPORT)\$(file)
###|$(TO_SUPPORT)\$(file)  : $(file)
###|                         @echo *** EXPORTING  : "$(file)" TO $(TO_SUPPORT)
###|                         @copy $(file) $(TO_SUPPORT) >nul
###|%endfor
###|%endif
###|
###|#------ SET UP RULES FOR EXPORTING TO SUPPORT (generated files) -------------
###|EXPORT_BEFORE_PASS_2 ::
###|%if %defined(TO_SUPPORT)
###|%foreach file in $(GENERATED_TO_SUPPORT_LIST)
###|EXPORT_BEFORE_PASS_2 :: $(TO_SUPPORT)\$(file)
###|$(TO_SUPPORT)\$(file)      : $(OUTPUT_DIRECTORY)\$(file)
###|                             @echo *** EXPORTING  : "$(OUTPUT_DIRECTORY)\$(file)" TO $(TO_SUPPORT)
###|                             @copy $(OUTPUT_DIRECTORY)\$(file) $(TO_SUPPORT) >nul
###|%endfor
###|%endif
###|
###|#------ SET UP RULES FOR EXPORTING TO PRODUCTION (generated files) ----------
###|EXPORT_AFTER_MAKE ::
###|%if %defined(TO_PRODUCTION)
###|%if %defined(SYM_TO_PRODUCTION)
###|%foreach file in $[w,$(OUTPUT_DIRECTORY)\*.SYM]
###|EXPORT_AFTER_MAKE :: $(TO_PRODUCTION)\$(file)
###|$(TO_PRODUCTION)\$(file)      : $(OUTPUT_DIRECTORY)\$(file)
###|                                @echo *** SYMBOL FILE: "$(OUTPUT_DIRECTORY)\$(file)" TO $(TO_PRODUCTION)
###|                                @copy $(OUTPUT_DIRECTORY)\$(file) $(TO_PRODUCTION) >nul
###|%endfor
###|%endif
###|%foreach file in $(GENERATED_TO_PRODUCTION_LIST)
###|EXPORT_AFTER_MAKE :: $(TO_PRODUCTION)\$(file)
###|$(TO_PRODUCTION)\$(file)      : $(OUTPUT_DIRECTORY)\$(file)
###|                                @echo *** EXPORTING  : "$(OUTPUT_DIRECTORY)\$(file)" TO $(TO_PRODUCTION)
###|                                @copy $(OUTPUT_DIRECTORY)\$(file) $(TO_PRODUCTION) >nul
###|%endfor
###|%foreach file in $(SOURCE_TO_PRODUCTION_LIST)
###|EXPORT_AFTER_MAKE :: $(TO_PRODUCTION)\$(file)
###|.SOURCE . $(file)
###|$(TO_PRODUCTION)\$(file)      : $(file)
###|                                @echo *** EXPORTING  : "$(file)" TO $(TO_PRODUCTION)
###|                                @copy $(file) $(TO_PRODUCTION) >nul
###|%endfor
###|%endif
###+--------------------------------------------------------------------------
###                    /* (Wednesday the 17/03/1993, 10:17:12) */


#### Deletes any files in the out directory #################################
DELETE_MAKE_OUTPUT:
                   -@ del $(OUTPUT_DIRECTORY)\*.* /N >nul 2>&1

#### Deletes any files which are not required (diagnostic) ##################
CLEANUP_AFTER_MAKE:
                   -@ del                     *.err >nul 2>&1
                   -@ del $(OUTPUT_DIRECTORY)\*.lst >nul 2>&1
#                   -@ del $(OUTPUT_DIRECTORY)\*.map >nul 2>&1



#############################################################################






#------ CREATING ".HLP" help file -------------------------------------------
.ipf.hlp:
        %do   CREATE_HLP_FILE

#------ CREATING ".INF" help file -------------------------------------------
.ipf.inf:
        %do   CREATE_INF_FILE



#------ CREATING MESSAGE FILE -----------------------------------------------
.txt.msg:
        %do   CREATE_MSG_FILE


#------ CREATING ".RES"  FILE -----------------------------------------------
.rc.res:
        %do   CREATE_PM_RES_FILE
.rcx.rc:
        %do   CREATE_RC_FILE_FROM_RCX


#------ SOM compiling rule (IDL is 'newer', in fact CSC may not work at all) ------
.idl.c:
        %do   DO_SOM_IDL_COMPILE
.idl.ih:
        %do   DO_SOM_IDL_COMPILE
.csc.c:
        %if %exists($[r,$*].IDL)
            %do   DO_SOM_IDL_COMPILE
        %else
            %do   DO_SOM_CSC_COMPILE
        %endif
.csc.ih:
        %if %exists($[r,$*].IDL)
            %do   DO_SOM_IDL_COMPILE
        %else
            %do   DO_SOM_CSC_COMPILE
        %endif


#------ CREATING OBJECTS (EXE = static link to C runtime & no ANZ DLL's) ----
.c.obj:
        %do   COMPILE_C_TO_OBJ
.cpp.obj:
        %do   COMPILE_CPP_TO_OBJ
.app.os:
        %do   COMPILE_APP_TO_OBJ


#------ CREATING OBJECTS (EXE = link with "C" runtime DLL & ANZ DLL's) ------
.c.ob:
        %do   COMPILE_C_TO_OB
.cpp.ob:
        %do   COMPILE_CPP_TO_OB
.app.od:
        %do   COMPILE_APP_TO_OB


#------ Creaing .CMD from .X & .XH files ------------------------------------
.PATH.x     = .
.PATH.xh    = .;$(OUTPUT_DIRECTORY);$(PrjInclude);$(INCLUDE)
.PATH.cmd   = $(OUTPUT_DIRECTORY);.
.x.cmd:
        %do   MAKE_REXX_PROCEDURE


#------ CREATING LIBRARY (link with .EXE) -----------------------------------
.obj.lib:
        %do   MAKE_LIBRARY

#------ CREATING LIBRARY (link with .EXE) -----------------------------------
.ob.lib:
        %do   MAKE_LIBRARY


#------ CREATING LIBRARY (Import library) -----------------------------------
.def.dil:
        %do   MAKE_DLL_IMPORT_LIBRARY

#------ CREATING HTML from .IT & .IH (header) files -------------------------
.it.htm:
        %do   CREATE_HTM_FROM_IT




##############################################################################
# The name of the message file needs the path due to typical IBM stupidity
##############################################################################
#
ADD_DDE4_MESSAGES_TO_EXE:
##############################################################################
        %do  AddBlankLines
        $(_IBM_MSG_BINDER) < <
>$*.exe
$[l,<]$(_IPFC_RUNTIME_MSG_FILE)
*
<



##############################################################################
CREATE_HLP_FILE:
##############################################################################
        %do    AddBlankLines
        #@%set _IpfName = $[r,$*].IPF
        @%set _IpfName = $<
        @echo *** Preprocessing "$(_IpfName)" (IPFCPREP.EXE) ****************
        %setenv INCLUDE=$(PrjInclude);.\$(OUTPUT_DIRECTORY);$(INCLUDE)
        $(_IBM_IPF_PREPROCESSOR)  $(_IpfName)   IPFCPREP.IPF
        copy   IPFCPREP.IPF $(OUTPUT_DIRECTORY)
        %do    AddBlankLines
        @echo *** Preprocessing "$(_IpfName)" (SRCHREPL.EXE) ****************
        $(_ANZ_IPF_PREPROCESSOR)  $(PrjSupportDir)\IPFXMP.IPF IPFCPREP.IPF SRCHREPL.IPF  $$StopTextChanges $$RemoveBlankLines > NULL
        copy   SRCHREPL.IPF $(OUTPUT_DIRECTORY)
        %do    AddBlankLines
        @echo *** MAKING HELP FILE "$(OUTPUT_DIRECTORY)\$[r,$*].HLP" *******************************
        $(_IBM_IPF_COMPILER)   SRCHREPL.IPF  $(_IPFC_HLP_FLAGS)
        copy   SRCHREPL.HLP $(OUTPUT_DIRECTORY)\$[r,$*].HLP
        @del   SRCHREPL.HLP
        @del   IPFCPREP.IPF
        @del   SRCHREPL.IPF


##############################################################################
CREATE_INF_FILE:
##############################################################################
        %do    AddBlankLines
        #@%set _IpfName = $[r,$*].IPF
        @%set _IpfName = $<
        @echo *** Preprocessing "$(_IpfName)" (IPFCPREP.EXE) ****************
        %setenv INCLUDE=$(PrjInclude);.\$(OUTPUT_DIRECTORY);$(INCLUDE)
        $(_IBM_IPF_PREPROCESSOR)  $(_IpfName)   IPFCPREP.IPF
        copy   IPFCPREP.IPF $(OUTPUT_DIRECTORY)
        %do    AddBlankLines
        @echo *** Preprocessing "$(_IpfName)" (SRCHREPL.EXE) ****************
        $(_ANZ_IPF_PREPROCESSOR) $(PrjSupportDir)\IPFXMP.IPF IPFCPREP.IPF SRCHREPL.IPF  $$StopTextChanges  $$RemoveBlankLines > NULL
        copy   SRCHREPL.IPF $(OUTPUT_DIRECTORY)
        %do    AddBlankLines
        @echo *** MAKING INF FILE "$(OUTPUT_DIRECTORY)\$[r,$*].INF" *******************************
        $(_IBM_IPF_COMPILER)   SRCHREPL.IPF  $(_IPFC_INF_FLAGS)
        copy   SRCHREPL.INF $(OUTPUT_DIRECTORY)\$[r,$*].INF
        @del   SRCHREPL.INF
        @del   IPFCPREP.IPF
        @del   SRCHREPL.IPF




##############################################################################
CREATE_MSG_FILE:
#                Use Full filenames in PATH because the message compiler
#                puts the full source name in the hypertext part of output!
##############################################################################
        %do    AddBlankLines
        @echo *** MAKING MSG FILE "$<" *******************************
        $(_ANZ_MSG_COMPILER)  $(PRJUSERDIR)\$(PRJPROJECT)\$[r,$*].TXT  $(PRJUSERDIR)\$(PRJPROJECT)\$(OUTPUT_DIRECTORY)\$[r,$*].MSG  keep
        copy   UTLMSGMK.ITF $*.itf
        copy   UTLMSGMK.MIH $*.mih
        @del   UTLMSGMK.ITF
        @del   UTLMSGMK.MIH
        @del   UTLMSGMK.IMF



#############################################################################
DO_SOM_IDL_COMPILE:
#############################################################################
        %do    AddBlankLines
        @echo *** DOING SOM COMPILE OF "$[r,$*].IDL" *******************
        %setenv   HPATH=$(CPPMAIN)\INCLUDE\OS2
        %setenv LIBPATH=$(CPPMAIN)\LIB
        %setenv INCLUDE=$(OUTPUT_DIRECTORY);$(INCLUDE);$(PrjSupportDir)
        %setenv  SMEMIT=ih;h;ph;def;psc;sc;c
        %if %exists($[r,$*].C)
            -copy $[r,$*].C  $(OUTPUT_DIRECTORY) >nul 2>&1
            %if   %status
              @echo.
              @echo *** COPY of "$[r,$*].C" TO "$(OUTPUT_DIRECTORY)" DIRECTORY FAILED...
              @%exit 197
            %endif
        %endif
        -SC   -v -r -S60000 -d$(OUTPUT_DIRECTORY) $[r,$*].IDL
        %if   %status
              @echo.
              @echo *** SOM COMPILE FAILED...
              @del $(OUTPUT_DIRECTORY)\$[r,$*].IH
              @%exit 198
        %else
              -copy $(OUTPUT_DIRECTORY)\$[r,$*].C .
              %if    %status
                    @echo.
                    @echo *** COPY of "$[r,$*].C" TO SOURCE DIRECTORY FAILED.
                    @echo *** YOU HAVE PROBABLY GOT the file loaded in an editor etc...
                    @del $(OUTPUT_DIRECTORY)\$[r,$*].IH
                    @%exit 199
              %else
                    -@del  $(OUTPUT_DIRECTORY)\$[r,$*].C >nul 2>&1
              %endif
        %endif


##############################################################################
DO_SOM_CSC_COMPILE:
##############################################################################
        %do    AddBlankLines
        @echo *** DOING SOM COMPILE OF "$[r,$*].CSC" *******************
        @echo.
        @echo NOTE: CSC compiles may no longer work, if required convert .CSC to .IDL
        @echo       This can be done with the CTOI utility although you will need
        @echo       access to the old .SC file, have fun....
        @echo.
#        %do     WorkOutWhere21ToolKitIs
#        @echo using TOOLKT21_DIR="$(TOOLKT21_DIR)"
#        %setenv HPATH=$(TOOLKT21_DIR)\C\OS2H
#        %setenv LIBPATH=$(TOOLKT21_DIR)\OS2LIB
#        %setenv SMINCLUDE=.;$(TOOLKT21_DIR)\SC;P:\IBMCPP3.08\INCLUDE\OS2;P:\IBMCPP3.08\INCLUDE\SOM;P:\IBMCPP3.08\INCLUDE;P:\IBMCPP3.08\som;
#        %setenv SMTMP=.\$(OUTPUT_DIRECTORY)
#        %setenv SMEMIT=ih;h;ph;def;psc;sc;c
#        call envtk2.cmd
#
#        %if %exists($[r,$*].C)
#            -copy $[r,$*].C  $(OUTPUT_DIRECTORY) >nul 2>&1
#            %if   %status
#              @echo.
#              @echo *** COPY of "$[r,$*].C" TO "$(OUTPUT_DIRECTORY)" DIRECTORY FAILED...
#              @%exit 297
#            %endif
#        %endif
#        -SC   -v -r -d$(OUTPUT_DIRECTORY) $[r,$*].CSC
#        %if   %status
#              @echo.
#              @echo *** SOM COMPILE FAILED...
#              @del $(OUTPUT_DIRECTORY)\$[r,$*].IH
#              @%exit 298
#        %else
#              -copy $(OUTPUT_DIRECTORY)\$[r,$*].C .
#              %if    %status
#                    @echo.
#                    @echo *** COPY of "$[r,$*].C" TO SOURCE DIRECTORY FAILED.
#                    @echo *** YOU HAVE PROBABLY GOT the file loaded in an editor etc...
#                    @del $(OUTPUT_DIRECTORY)\$[r,$*].IH
#                    @%exit 299
#              %else
#                    -@del  $(OUTPUT_DIRECTORY)\$[r,$*].C >nul 2>&1
#              %endif
#        %endif
#

##############################################################################
WorkOutWhere21ToolKitIs:
##############################################################################
        %if %exists(D:\TOOLKT21\C\OS2H\OS2.H)
            @%set TOOLKT21_DIR = D:\TOOLKT21
        %else
            %if %exists(C:\TOOLKT21\C\OS2H\OS2.H)
                @%set TOOLKT21_DIR = C:\TOOLKT21
            %else
                %if %exists(p:\os2tk21\C\OS2H\OS2.H)
                    @%set TOOLKT21_DIR = p:\os2tk21
#                @%set TOOLKT21_DIR = S:\TOOLKT21
                %else
                    @echo ####### ERROR - TOOLKT21_DIR not found (PRJVAC30.mak #500)
                    @%exit 1
                %endif
            %endif
        %endif


##############################################################################
CREATE_RC_FILE_FROM_RCX:
##############################################################################
        %do    AddBlankLines
        @%set  _FullTargetName   = $@
        @%set  _FullSourceName   = $<
        @%set  _TheIccOutputFile = $[p, $(_FullSourceName)]$[r, $(_FullSourceName)].I
        @echo *** MAKING PM RESOURCE FILE "$(_FullTargetName)" from "$(_FullSourceName)" *******************
        @echo.
        ICC /c /Q /Pc+ /Pe+ $(_FullSourceName)
        @copy $(_TheIccOutputFile) $(_FullTargetName) > nul
        @del  $(_TheIccOutputFile) > nul 2>&1



##############################################################################
CREATE_PM_RES_FILE:
##############################################################################
        %do    AddBlankLines
        @echo *** MAKING PM RESOURCE FILE "$*.res" *******************
        %setenv INCLUDE=$(OUTPUT_DIRECTORY);$(INCLUDE);$(PrjSupportDir)
        $(_IBM_RESOURCE_COMPILER) $(_CREATE_RESOURCE_FLAGS)  $<  $*.res


##############################################################################
COMPILE_C_TO_OBJ:
##############################################################################
        %if %defined(DEBUG_WITH_IPMD)
            @%set   COMPILE_FLAGS = $(_C_COMPILE_FLAGS_OBJ) $(C_FLAGS_OBJ) $(_COMPILE_DEBUG)
        %else
            @%set   COMPILE_FLAGS = $(_C_COMPILE_FLAGS_OBJ) $(C_FLAGS_OBJ)
        %endif
        %do     COMPILE_C_OR_CPP_MODULE


##############################################################################
COMPILE_CPP_TO_OBJ:
##############################################################################
        %if %defined(DEBUG_WITH_IPMD)
            @%set   COMPILE_FLAGS = $(_CPP_COMPILE_FLAGS_OBJ) $(CPP_FLAGS_OBJ) $(_COMPILE_DEBUG)
        %else
            @%set   COMPILE_FLAGS = $(_CPP_COMPILE_FLAGS_OBJ) $(CPP_FLAGS_OBJ)
        %endif
        %do     COMPILE_C_OR_CPP_MODULE


##############################################################################
COMPILE_APP_TO_OBJ:
##############################################################################
        %if %defined(DEBUG_WITH_IPMD)
            @%set   COMPILE_FLAGS = $(_APP_COMPILE_FLAGS_OBJ) $(APP_FLAGS_OBJ) $(_COMPILE_DEBUG)
        %else
            @%set   COMPILE_FLAGS = $(_APP_COMPILE_FLAGS_OBJ) $(APP_FLAGS_OBJ)
        %endif
        %if     $(_AddPvHandlerToAppModules) != "No"
                %do   COMPILE_APP_MODULE_SO_AS_TO_ADD_PV_HANDLER
        %else
                %do   COMPILE_C_OR_CPP_MODULE
        %endif



##############################################################################
COMPILE_C_TO_OB:
##############################################################################
        %if %defined(DEBUG_WITH_IPMD)
            @%set   COMPILE_FLAGS = $(_C_COMPILE_FLAGS_OB) $(C_FLAGS_OB) $(_COMPILE_DEBUG)
        %else
            @%set   COMPILE_FLAGS = $(_C_COMPILE_FLAGS_OB) $(C_FLAGS_OB)
        %endif
        %do     COMPILE_C_OR_CPP_MODULE


##############################################################################
COMPILE_CPP_TO_OB:
##############################################################################
        %if %defined(DEBUG_WITH_IPMD)
            @%set   COMPILE_FLAGS = $(_CPP_COMPILE_FLAGS_OB) $(CPP_FLAGS_OB) $(_COMPILE_DEBUG)
        %else
            @%set   COMPILE_FLAGS = $(_CPP_COMPILE_FLAGS_OB) $(CPP_FLAGS_OB)
        %endif
        %do     COMPILE_C_OR_CPP_MODULE


##############################################################################
COMPILE_APP_TO_OB:
##############################################################################
        %if %defined(DEBUG_WITH_IPMD)
            @%set   COMPILE_FLAGS = $(_APP_COMPILE_FLAGS_OB) $(APP_FLAGS_OB) $(_COMPILE_DEBUG)
        %else
            @%set   COMPILE_FLAGS = $(_APP_COMPILE_FLAGS_OB) $(APP_FLAGS_OB)
        %endif
        %if     $(_AddPvHandlerToAppModules) != "No"
                %do   COMPILE_APP_MODULE_SO_AS_TO_ADD_PV_HANDLER
        %else
                %do   COMPILE_C_OR_CPP_MODULE
        %endif


##############################################################################
COMPILE_APP_MODULE_SO_AS_TO_ADD_PV_HANDLER:
#
#       This routine will ensure the file that is compiled includes
#       "<UTLFAULT.H>" and sets up the handler pragma.
##############################################################################
        #### Say what happening & set up INCLUDE variable ###################
        @%set _SourceApp   = $<
        @%set _ModifiedApp = $(OUTPUT_DIRECTORY)\$[r,$(_SourceApp)].$[e,$(_SourceApp)]
        %do  AddBlankLines
        @echo *** COMPILING "$(_SourceApp)" (Adding UTL 'PV' Handler) ****************
        %setenv INCLUDE=.;$(PrjInclude);.\$(OUTPUT_DIRECTORY);$(INCLUDE)

        #### Add the required stuff to the code #############################
        @copy $(_SourceApp) $(_ModifiedApp) >nul
        @echo.                                                                              >> $(_ModifiedApp)
        @echo  /* Inserted by "COMPILE_APP_MODULE_SO_AS_TO_ADD_PV_HANDLER" in $(MakName) */ >> $(_ModifiedApp)
        @echo  \#include ^<OS2.H^>                                                          >> $(_ModifiedApp)
        @echo  \#include ^<UtlFault.H^>                                                     >> $(_ModifiedApp)
        @echo  \#pragma  handler(main)    /* Add ANZ PV handler */                          >> $(_ModifiedApp)

        ### Perform the compile ###################################################
        $(_DB_BETTER_TEE) $[r,$(_SourceApp)].err "$(_IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$@ $(_ModifiedApp)"


##############################################################################
COMPILE_C_OR_CPP_MODULE:
##############################################################################
        %do  AddBlankLines
        @echo *** COMPILING "$<" *******************************
        %setenv INCLUDE=$(PrjInclude);.\$(OUTPUT_DIRECTORY);$(INCLUDE)
        $(_DB_BETTER_TEE) $[r,$<].err "$(_IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$@ $<"


##############################################################################
MAKE_REXX_PROCEDURE:
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING  "$@" *******************************
        %setenv INCLUDE=$(PrjInclude);.\$(OUTPUT_DIRECTORY);$(INCLUDE)
        %if "$(_USE_REXXIT_4_X2CMD)" = "YES"
            >-$(_ANZ_REXX_PREPROCESSOR)  $<  $@  $(REXXIT_FLAGS)
        %else
            >-$(_PPWIZARD_PREPROCESSOR)  $<  /rexx /Color:N /Output:$@  $(_PPWIZARD_2REXX_FLAGS)
        %endif
        %if ! %status
            ### Compile worked, delete any existing .ERR files (from previous failure) ###
            %if %exists($*.ERR)
                -@ del $*.ERR > nul 2>&1
            %endif
         %else
            ### Compile failed, rename generated file ####################################
            %if %exists($@)
                @echo *** Renaming $@ to $*.ERR ***
                @ copy $@ $*.ERR > nul
                @ del $@
            %endif
            @ %exit 399
        %endif



##############################################################################
CREATE_HTM_FROM_IT:
##############################################################################
        %do    AddBlankLines
        @echo ***
        @echo *** MAKING HTML FILE "$@" *******************************
        @echo ***
        >-$(_ANZ_HTML_PREPROCESSOR)  $<  /Output:$(OUTPUT_DIRECTORY)\*.htm  /Color:N $(PPWIZARD_FLAGS)
        %do  DELETE_TARGET_ON_NOZERO_RC



##############################################################################
MAKE_DLL_IMPORT_LIBRARY:
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING LIBRARY "$@" *******************************
        %if %exists($@)
            del $@
        %endif
        >-$(_IBM_IMPLIB) $@  $<
        %do  DELETE_TARGET_ON_NOZERO_RC




##############################################################################
MAKE_LIBRARY:
##############################################################################
        #### Tell user what we are doing & delete any existing library file ###
        %do  AddBlankLines
        @echo *** MAKING LIBRARY "$@" *******************************
        %if %exists($@)
            del $@
        %endif

        #### Work through each file in list (make sure all files have extn .OBJ) ###
        @%set   _LibObjectList =
        %foreach _LibThisObject in $**
                #### Get the details about this object file from the list ###
                @%set   _LibThisObjectPath = $[p, $(_LibThisObject)]
                @%set   _LibThisObjectRoot = $[r, $(_LibThisObject)]
                @%set   _LibThisObjectExtn = $[e, $(_LibThisObject)]

                #### Is the extension ".OBJ"? ###############################
                %if     $(_LibThisObjectExtn) != "OBJ"
                        #### Need to convert to ".OBJ" (work out its new name) ###
                        @%set   _LibNewObjectName = $(TempObjPathForLibrarian)\$(_LibThisObjectRoot).OBJ

                        #### Make directory for new file & copy it ##########
                        ~@md    $(TempObjPathForLibrarian) > nul 2>&1
                        @echo        * Copying $(_LibThisObject) --^> $(_LibNewObjectName)
                        @copy   $(_LibThisObject) $(_LibNewObjectName) >nul

                        #### Update new name ################################
                        @%set   _LibThisObject = $(_LibNewObjectName)
                %endif

                #### Add the current filename to the list ###################
                @%set   _LibObjectList = $(_LibObjectList) $(_LibThisObject)
        %endfor

        #### Now create response file #######################################
        @ copy < <
            $@
            y
            +$[s," &\n            +",$(_LibObjectList)]
            $*.lst
            ;
<  $*._CL >nul

        #### Now call the librarian to create the library ###################
        >-  $(_LIBRARIAN) $(_LIB_FLAGS) $(LIB_FLAGS)  @$*._CL
        %do DELETE_TARGET_ON_NOZERO_RC

        #### Now lets delete any temporary ".OBJ" files etc #################
        ~@del  $(TempObjPathForLibrarian) /n > nul 2>&1
        ~@rd   $(TempObjPathForLibrarian)    > nul 2>&1




############################################################################
MAKE_EXE_PM:
############################################################################
        @%set _OLD_          = $(LINK_FLAGS_EXE)
        @%set LINK_FLAGS_EXE = $(_OLD_) /PMTYPE:PM
        %do   MAKE_EXE
        @%set LINK_FLAGS_EXE = $(_OLD_)


##############################################################################
MAKE_EXE:
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING EXECUTABLE "$@" *******************************
         %setenv LIB=$(PrjLib);$(LIB)
         @%set  CRTIMEDLL = $[m,*.ob,$**]$[m,*.dil,$**]
         %if "$(CRTIMEDLL)" == ""
             @echo *** STATIC LINK WITH "C" runtime (and ANZ .LIBS's if used).
             @%set _MAKE_EXE_TMP_FLAG_ =
         %else
             @echo *** DYNAMIC LINK WITH "C" runtime (and ANZ .DIL's if used).
             @%set _MAKE_EXE_TMP_FLAG_ = /NOI
         %endif
         %if %defined(DEBUG_WITH_IPMD)
             @%set   FLAGS_FOR_LINK = $(_MAKE_EXE_TMP_FLAG_) $(_LINK_FLAGS_EXE) $(LINK_FLAGS_EXE) $(LINK_FLAGS) $(_LINK_DEBUG)
         %else
             @%set   FLAGS_FOR_LINK = $(_MAKE_EXE_TMP_FLAG_) $(_LINK_FLAGS_EXE) $(LINK_FLAGS_EXE) $(LINK_FLAGS)
         %endif
         @ %set L_O       = $[m,*.obj,$**] $[m,*.ob,$**] $[m,*.os,$**] $[m,*.od,$**]
         @ %set L_L       = $[m,*.lib,$**] $[m,*.dil,$**]
         @ copy < <
            $(FLAGS_FOR_LINK) +
            $[s,"+\n            ",$(L_O)]
            $*.exe
            $*.map
            $[s,"+\n            ",$(L_L)]
            $[m,*.def,$**];
<  $*._LE >nul
        @echo $(_IBM_32BIT_LINKER) @$*._LE
        @type $*._LE
        @echo.
        @>-  $(_IBM_32BIT_LINKER) @$*._LE
        %if "$(EXE_LINK_WARNINGS_OK)" = "YES"
             %do  DELETE_TARGET_ON_NOZERO_RC_EXCEPT_WARNINGS
        %else
             %do  DELETE_TARGET_ON_NOZERO_RC
        %endif
        %do  MAKE_SYM_FOR_KERNAL_DEBUGGER
        %do  ADD_RES_FILES_TO_EXE_OR_DLL
        %do  COMPRESS_OBJECT_USING_LXLITE



##############################################################################
MAKE_DLL:
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING DLL "$@" *******************************
         %setenv LIB=$(PrjLib);$(LIB)

         ##### MAKE & LINK DUMMY DLL IF REQUIRED ##############################
         @%set  CRTIMEDLL = $[m,*.ob,$**]$[m,*.dil,$**]
         %if "$(CRTIMEDLL)" == ""
                @echo *** MAKING A "NORMAL" DLL (everything statically linked).
                @%set _MAKE_EXE_TMP_FLAG_ =
                @%set DUMMY_DLL_OBJECT  = $(OUTPUT_DIRECTORY)\DLLDUMY.OBJ
                @%set DUMMY_DLL_CSOURCE = .\DLLDUMY
                %if ! %exists($(DUMMY_DLL_OBJECT))
                        @echo *** NEED TO MAKE "$(DUMMY_DLL_OBJECT)" **************************
                        @echo /* No code. Compiled to supply DLL init code */ > $(DUMMY_DLL_CSOURCE).C
                        @%set COMPILE_FLAGS = $(_COMPILE_FLAGS_DUMMY_OBJ)
                        @REM $(_IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT)  $(DUMMY_DLL_CSOURCE).C | teers $(DUMMY_DLL_CSOURCE).ERR
                        $(_DB_BETTER_TEE) $(DUMMY_DLL_CSOURCE).ERR "$(_IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT) $(DUMMY_DLL_CSOURCE).C"
                        @del $(DUMMY_DLL_CSOURCE).C
                %endif
         %else
                @echo *** MAKING A "ANZ" utility DLL (C-runtime dynamically linked as well).
                @%set _MAKE_EXE_TMP_FLAG_ = /NOI
                @%set DUMMY_DLL_OBJECT  = $(OUTPUT_DIRECTORY)\DLLDUMY.OB
                @%set DUMMY_DLL_CSOURCE = .\DLLDUMY
                %if ! %exists($(DUMMY_DLL_OBJECT))
                        @echo *** NEED TO MAKE "$(DUMMY_DLL_OBJECT)" **************************
                        @echo /* No code. Compiled to supply DLL init code */ > $(DUMMY_DLL_CSOURCE).C
                        @%set COMPILE_FLAGS = $(_COMPILE_FLAGS_DUMMY_OB)
                        @REM $(_IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT)  $(DUMMY_DLL_CSOURCE).C | teers $(DUMMY_DLL_CSOURCE).ERR
                        $(_DB_BETTER_TEE) $(DUMMY_DLL_CSOURCE).ERR "$(_IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT) $(DUMMY_DLL_CSOURCE).C"
                        @del $(DUMMY_DLL_CSOURCE).C
                %endif
         %endif

         %if %defined(DEBUG_WITH_IPMD)
             @%set   FLAGS_FOR_LINK = $(_MAKE_EXE_TMP_FLAG_) $(_LINK_FLAGS_DLL) $(LINK_FLAGS_DLL) $(LINK_FLAGS) $(_LINK_DEBUG)
         %else
             @%set   FLAGS_FOR_LINK = $(_MAKE_EXE_TMP_FLAG_) $(_LINK_FLAGS_DLL) $(LINK_FLAGS_DLL) $(LINK_FLAGS)
         %endif
         @ %set L_O       = $[m,*.obj,$**] $[m,*.ob,$**]  $[m,*.os,$**] $[m,*.od,$**] $(DUMMY_DLL_OBJECT)
         @ %set L_L       = $[m,*.lib,$**] $[m,*.dil,$**]
         @ copy < <
            $(FLAGS_FOR_LINK) +
            $[s,"+\n            ",$(L_O)]
            $*.dll
            $*.map
            $[s,"+\n            ",$(L_L)]
            $[m,*.def,$**];
<  $*._LD >nul
        @echo $(_IBM_32BIT_LINKER) @$*._LD
        @type $*._LD
        @echo.
        @>-  $(_IBM_32BIT_LINKER) @$*._LD
        %do  DELETE_TARGET_ON_NOZERO_RC
        %do  MAKE_SYM_FOR_KERNAL_DEBUGGER
        %do  ADD_RES_FILES_TO_EXE_OR_DLL
        %do  COMPRESS_OBJECT_USING_LXLITE



##############################################################################
COMPRESS_OBJECT_USING_LXLITE:
#
#  Use LXLITE to compress the generate executable (if wanted etc)
##############################################################################
       ##### See if we want to Compress ######################################
       %if "$(_LXLITE_ENABLED)" = "YES"
           ##### Have we got debug mode on? ##################################
           %if %defined(DEBUG_WITH_IPMD)
               ##### Don't compress if debug mode is on ######################
               @%set   _DoLxLite_ = NO
           %else
               #### #### Yes Lets compress! ##################################
               @%set   _DoLxLite_ = YES
           %endif
       %else
           #### LXLITE is not enabled ########################################
           @%set   _DoLxLite_ = NO
       %endif

       #### Compress if we have decided we need to ###########################
       %if "$(_DoLxLite_)" = "YES"
           @echo.
           @echo *** Compressing "$@" *******************************
           -$(_LXITE)  $(_LXLITE_FLAGS) $(LXLITE_FLAGS) $@
           %do  DELETE_TARGET_ON_NOZERO_RC
       %endif




##############################################################################
ADD_RES_FILES_TO_EXE_OR_DLL:
#
#  Note that we need to do the 2 eautil commands because of a bug in the
#  resource compiler where EAs in the file are lost.  This does currently
#  matter, for example HWPW.EXE does care (security check).
##############################################################################
        @ %set ADD_1_RES = $[m,*.res,$**]
        %foreach RES_FILE in $(ADD_1_RES)
                 @echo ***
                 @echo *** ADDING "$(RES_FILE)" FILES to "$@" *******************************
                 >-$(_OS2_EAUTIL) $@  $*.EA /S /R /P
                 %do  DELETE_TARGET_ON_NOZERO_RC
                 -$(_IBM_RESOURCE_COMPILER)  $(_ADD_RESOURCE_2EXE_FLAGS) $(RES_FILE) $@
                 %do  DELETE_TARGET_ON_NOZERO_RC
                 >-$(_OS2_EAUTIL) $@  $*.EA /J /M
                 %do  DELETE_TARGET_ON_NOZERO_RC
        %endfor

##############################################################################
MAKE_SYM_FOR_KERNAL_DEBUGGER:
##############################################################################
        %if     "$(_MAPSYM_ENABLED)" = "YES"
                %do    AddBlankLines
                @echo *** MAKING KERNAL DEBUGGER SYMBOL FILE "$*.SYM" ******************
                @cd $(OUTPUT_DIRECTORY) && $(_IBM_MAPSYM) $(_MAPSYM_OPTIONS) $[r,$*].map
                @echo *** MAKING EXCEPTQ SYMBOL FILE "$*.xqs ***************************
                $(MX) $(MXFLAGS) $*.map -o $*.xqs
        %endif



##############################################################################
DELETE_TARGET_ON_NOZERO_RC:
##############################################################################
        %if %status
            %if %exists($@)
                @echo *** DELETING the target ($@) due to nonzero RC.
                @ del $@
            %else
                @echo *** NO TARGET ($@) to delete due to nonzero RC.
            %endif
            @ %exit 499
        %endif

#############################################################################
DELETE_TARGET_ON_NOZERO_RC_EXCEPT_WARNINGS:
#############################################################################
        %if %status > 4
            %if %exists($@)
                @echo *** DELETING the target ($@) due to RC > 4.
                @ del $@
            %else
                @echo *** NO TARGET ($@) to delete due to RC > 4.
            %endif
            @ %exit 599
        %endif



##############################################################################
AddBlankLines:
##############################################################################
        @echo.
        @echo.


