#*---------------------------------------------------------------------------+
#
#     MODULE NAME:   SUE_DB.MAK
#
#         $Author:   Dennis_Bareis  $
#                    Andreas Buchinger  2009-2024
#       $Revision:   1.28  $
#           $Date:   21 Apr 1995 15:53:54  $
#        $Logfile:   V:/SUEPVCS/SUPPORT/SUE_DB.MAV  $
#
#     DESCRIPTION:   Include file for all SUE make files..
#
#     UNUSUAL EXTENSIONS:
#     ~~~~~~~~~~~~~~~~~~
#                    .DIL   - DLL Import library (used in place of .LIB).
#                    .OB    - An object (.OBJ) compiled with "/Gd+" and NOT "/Gd-".  When linked "/NOI" is
#                             automatically used.
#                    ._xx   - In the output directory are "temporary" files used in LIBs/LINKs and kept for debugging.
#
#
#     SOME IMPORTANT DETAILS
#     ~~~~~~~~~~~~~~~~~~~~~~
#          (a)  TO USE ANZ DLLs or C runtime DLLs
#               ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#               You must include only ".OB" files (not ".obj"). And if using
#               general ANZ routines UTL, MSG, LOG etc then use ".DIL" when
#               linking.
#
#          (b)  TO USE ANZ LIBs or C static link
#               ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#               You must include only ".OBJ" files (not ".ob"). And if using
#               general ANZ routines UTL, MSG, LOG etc then use ".LIB" when
#               linking.
#
#          Note it is possible that you can override the need for the above
#          if /NOI is used when linking and default library searching is disabled
#          as well.  UNTESTED as yet!
#
#---------------------------------------------------------------------------*/

OUTPUT_DIRECTORY = .\OUT
.PATH.c     = .
.PATH.h     = .;$(OUTPUT_DIRECTORY);$(INCLUDE)
.PATH.rc    = .
.PATH.txt   = .
.PATH.err   = .
.PATH.hlp   = .
.PATH.ipf   = .;$(SUPPORT)
.PATH.iph   = .;$(SUPPORT)
.PATH.xmp   = .;$(SUPPORT)
.PATH.mih   = .;$(SUPPORT)
.PATH.inf   = $(OUTPUT_DIRECTORY)
.PATH.def   = .;$(OUTPUT_DIRECTORY)
.PATH.ih    = $(OUTPUT_DIRECTORY)
.PATH.hlp   = $(OUTPUT_DIRECTORY)
.PATH.obj   = $(OUTPUT_DIRECTORY)
.PATH.ob    = $(OUTPUT_DIRECTORY)
.PATH.res   = $(OUTPUT_DIRECTORY)
.PATH.exe   = $(OUTPUT_DIRECTORY)
.PATH.dll   = $(OUTPUT_DIRECTORY)
.PATH.lib   = $(OUTPUT_DIRECTORY);$(LIB)
.PATH.dil   = $(OUTPUT_DIRECTORY);$(LIB)
.PATH.itf   = $(OUTPUT_DIRECTORY)
.PATH.msg   = $(OUTPUT_DIRECTORY)
.PATH.map   = $(OUTPUT_DIRECTORY)

#############################################################################
### Need $(SUPPORT) in the following "PATH.lst" so as the handle the
### imbed of "SUEPROJ.LST" in the PMANUAL project.
#############################################################################
.PATH.lst   = $(OUTPUT_DIRECTORY);.;$(SUPPORT)


LIBRARIAN        = LIB.EXE
IBM_C_COMPILER   = ICC.EXE
IBM_32BIT_LINKER = LINK386.EXE



#############################################################################

#------ SET UP THE DEFAULT RULE ---------------------------------------------
# 20090816 removed from TOTAL:        CLEANUP_AFTER_MAKE           \
TOTAL:                               \
        EXPORT_BEFORE_PASS_1         \
        MAKE_IN_PASS1                \
        EXPORT_BEFORE_PASS_2         \
        MAKE_IN_PASS2                \
        EXPORT_AFTER_MAKE


#------ SET UP RULES FOR A PERSON ON A SINGLE PROJECT WANTING TO EXPORT -----
EXPORT:
        EXPORT_BEFORE_PASS_1         \
        EXPORT_BEFORE_PASS_2         \
        EXPORT_AFTER_MAKE



#------ SET UP LISTS FOR THINGS TO MAKE IN EACH PASS ------------------------
MAKE_IN_PASS1:  $(MAKE_IN_PASS1_LIST)
MAKE_IN_PASS2:  $(MAKE_IN_PASS2_LIST)

#----- SET these up in case SUEEXPRT.MAK is not used ------------------------
EXPORT_BEFORE_PASS_1 ::
        %do  AddBlankLines
EXPORT_BEFORE_PASS_2 ::
        %do  AddBlankLines
EXPORT_AFTER_MAKE    ::
        %do  AddBlankLines

###      CommentBlock  /* (Wednesday the 17/03/1993, 10:17:12) */
###+--------------------------------------------------------------------------
###|#------ SET UP RULES FOR EXPORTING TO SUPPORT (initial) ---------------------
###|EXPORT_BEFORE_PASS_1 ::
###|%if %defined(TO_SUPPORT)
###|%foreach file in $(FILES_TO_SUPPORT_LIST)
###|EXPORT_BEFORE_PASS_1 :: $(TO_SUPPORT)\$(file)
###|$(TO_SUPPORT)\$(file)  : $(file)
###|                         @echo *** EXPORTING  : "$(file)" TO $(TO_SUPPORT)
###|                         @copy $(file) $(TO_SUPPORT) >nul
###|%endfor
###|%endif
###|
###|#------ SET UP RULES FOR EXPORTING TO SUPPORT (generated files) -------------
###|EXPORT_BEFORE_PASS_2 ::
###|%if %defined(TO_SUPPORT)
###|%foreach file in $(GENERATED_TO_SUPPORT_LIST)
###|EXPORT_BEFORE_PASS_2 :: $(TO_SUPPORT)\$(file)
###|$(TO_SUPPORT)\$(file)      : $(OUTPUT_DIRECTORY)\$(file)
###|                             @echo *** EXPORTING  : "$(OUTPUT_DIRECTORY)\$(file)" TO $(TO_SUPPORT)
###|                             @copy $(OUTPUT_DIRECTORY)\$(file) $(TO_SUPPORT) >nul
###|%endfor
###|%endif
###|
###|#------ SET UP RULES FOR EXPORTING TO PRODUCTION (generated files) ----------
###|EXPORT_AFTER_MAKE ::
###|%if %defined(TO_PRODUCTION)
###|%if %defined(SYM_TO_PRODUCTION)
###|%foreach file in $[w,$(OUTPUT_DIRECTORY)\*.SYM]
###|EXPORT_AFTER_MAKE :: $(TO_PRODUCTION)\$(file)
###|$(TO_PRODUCTION)\$(file)      : $(OUTPUT_DIRECTORY)\$(file)
###|                                @echo *** SYMBOL FILE: "$(OUTPUT_DIRECTORY)\$(file)" TO $(TO_PRODUCTION)
###|                                @copy $(OUTPUT_DIRECTORY)\$(file) $(TO_PRODUCTION) >nul
###|%endfor
###|%endif
###|%foreach file in $(GENERATED_TO_PRODUCTION_LIST)
###|EXPORT_AFTER_MAKE :: $(TO_PRODUCTION)\$(file)
###|$(TO_PRODUCTION)\$(file)      : $(OUTPUT_DIRECTORY)\$(file)
###|                                @echo *** EXPORTING  : "$(OUTPUT_DIRECTORY)\$(file)" TO $(TO_PRODUCTION)
###|                                @copy $(OUTPUT_DIRECTORY)\$(file) $(TO_PRODUCTION) >nul
###|%endfor
###|%foreach file in $(SOURCE_TO_PRODUCTION_LIST)
###|EXPORT_AFTER_MAKE :: $(TO_PRODUCTION)\$(file)
###|.SOURCE . $(file)
###|$(TO_PRODUCTION)\$(file)      : $(file)
###|                                @echo *** EXPORTING  : "$(file)" TO $(TO_PRODUCTION)
###|                                @copy $(file) $(TO_PRODUCTION) >nul
###|%endfor
###|%endif
###+--------------------------------------------------------------------------
###                    /* (Wednesday the 17/03/1993, 10:17:12) */


#### Deletes any files in the out directory #################################
DELETE_MAKE_OUTPUT:
                   -@ del $(OUTPUT_DIRECTORY)\*.* /N >nul 2>&1

#### Deletes any files which are not required (diagnostic) ##################
CLEANUP_AFTER_MAKE:
                   -@ del                     *.err >nul 2>&1
                   -@ del $(OUTPUT_DIRECTORY)\*.lst >nul 2>&1
                   -@ del $(OUTPUT_DIRECTORY)\*.map >nul 2>&1



#############################################################################






#------ CREATING ".HLP" help file -------------------------------------------
.ipf.hlp:
        @echo new ipf file $*
        %do   CREATE_HLP_FILE

#------ CREATING ".INF" help file -------------------------------------------
.ipf.inf:
        @echo new ipf file $*
        %do   CREATE_INF_FILE



#------ CREATING MESSAGE FILE -----------------------------------------------
.txt.msg:
        %do   CREATE_MSG_FILE


#------ CREATING ".RES"  FILE -----------------------------------------------
.rc.res:
        %do   CREATE_PM_RES_FILE


#------ SOM compiling rule ('C' code skeleton originally generated by SOM) --
###      CommentBlock  /* (Monday 22/04/1996, 10:46:20, by Brett_Stas) */
###+--------------------------------------------------------------------------
###|.csc.c:
###|        %do   DO_SOM_COMPILE
###|.csc.ih:
###|        %do   DO_SOM_COMPILE
###+--------------------------------------------------------------------------
###                    /* (Monday 22/04/1996, 10:46:20, by Brett_Stas) */
.idl.c:
        %do     DO_SOM_COMPILE_OF_IDL
.idl.ih:
        %do     DO_SOM_COMPILE_OF_IDL



#------ CREATING OBJECTS (EXE = static link to C runtime & no ANZ DLL's) ----
.c.obj:
        @%set COMPILE_FLAGS = $(CEXE_FLAGS) /Gd- /Q /W3 /Wpro
        %do   C_COMPILE


#------ CREATING OBJECTS (EXE = link with "C" runtime DLL & ANZ DLL's) ------
.c.ob:
        @%set COMPILE_FLAGS = $(CEXE_FLAGS) /Gd+ /Q /W3 /Wpro
        %do   C_COMPILE


#------ Creaing .CMD from .X & .XH files ------------------------------------
.PATH.x     = .
.PATH.xh    = .;$(INCLUDE)
.PATH.cmd   = $(OUTPUT_DIRECTORY);.
.x.cmd:
        %do   MAKE_REXX_PROCEDURE


#------ CREATING LIBRARY (link with .EXE) -----------------------------------
.obj.lib:
        %do   MAKE_LIBRARY

#------ CREATING LIBRARY (link with .EXE) -----------------------------------
.ob.lib:
        %do   MAKE_LIBRARY


#------ CREATING LIBRARY (link with .EXE) -----------------------------------
.def.dil:
        %do   MAKE_DLL_IMPORT_LIBRARY

#------ CREATING EXE  -------------------------------------------------------
.obj.exe:
        %do   MAKE_EXE

#------ CREATING DLL  -------------------------------------------------------
.obj.dll:
        %do   MAKE_DLL





##############################################################################
CREATE_HLP_FILE:
##############################################################################
#        %do    AddBlankLines
        @echo *** Preprocessing "$[r,$*].IPF" (IPFCPREP.EXE) ****************
        IPFCPREP.EXE  $[r,$*].IPF   IPFCPREP.IPF
        copy   IPFCPREP.IPF $(OUTPUT_DIRECTORY)
        %do    AddBlankLines
        @echo *** Preprocessing "$[r,$*].IPF" (SRCHREPL.EXE) ****************
        SRCHREPL.EXE  $(SUPPORT)\IPFXMP.IPF IPFCPREP.IPF SRCHREPL.IPF  $$StopTextChanges $$RemoveBlankLines
        copy   SRCHREPL.IPF $(OUTPUT_DIRECTORY)
        %do    AddBlankLines
        @echo *** MAKING HELP FILE "$(OUTPUT_DIRECTORY)\$[r,$*].HLP" *******************************
        IPFC   SRCHREPL.IPF  /S
        copy   SRCHREPL.HLP $(OUTPUT_DIRECTORY)\$[r,$*].HLP
        @del   SRCHREPL.HLP
        @del   IPFCPREP.IPF
        @del   SRCHREPL.IPF


##############################################################################
CREATE_INF_FILE:
##############################################################################
        %do    AddBlankLines
        @echo *** Preprocessing "$[r,$*].IPF" (IPFCPREP.EXE) ****************
        IPFCPREP.EXE  $[r,$*].IPF   IPFCPREP.IPF
        copy   IPFCPREP.IPF $(OUTPUT_DIRECTORY)
        %do    AddBlankLines
        @echo *** Preprocessing "$[r,$*].IPF" (SRCHREPL.EXE) ****************
        SRCHREPL.EXE  $(SUPPORT)\IPFXMP.IPF IPFCPREP.IPF SRCHREPL.IPF  $$StopTextChanges  $$RemoveBlankLines
        copy   SRCHREPL.IPF $(OUTPUT_DIRECTORY)
        %do    AddBlankLines
        @echo *** MAKING INF FILE "$(OUTPUT_DIRECTORY)\$[r,$*].INF" *******************************
        IPFC   SRCHREPL.IPF  /INF
        copy   SRCHREPL.INF $(OUTPUT_DIRECTORY)\$[r,$*].INF
        @del   SRCHREPL.INF
        @del   IPFCPREP.IPF
        @del   SRCHREPL.IPF



###      CommentBlock  /* (Friday the 11/06/1993, 13:28:04) */
###+--------------------------------------------------------------------------
###|##############################################################################
###|CREATE_HLP_FILE:
###|##############################################################################
###|        %do   AddBlankLines
###|        @echo *** MAKING HLP FILE "$<" *******************************
###|        IPFC   $<  /S
###|        copy   $[r,$*].hlp $(OUTPUT_DIRECTORY)
###|        @del   $[r,$*].hlp
###|
###|##############################################################################
###|CREATE_INF_FILE:
###|##############################################################################
###|        %do    AddBlankLines
###|        @echo *** MAKING INF FILE "$<" *******************************
###|        IPFC   $<  /INF
###|        copy   $[r,$*].inf $(OUTPUT_DIRECTORY)
###|        @del   $[r,$*].inf
###+--------------------------------------------------------------------------
###                    /* (Friday the 11/06/1993, 13:28:04) */




##############################################################################
CREATE_MSG_FILE:
#                Use Full filenames in PATH because the message compiler
#                puts the full source name in the hypertext part of output!
##############################################################################
        %do    AddBlankLines
        @echo *** MAKING MSG FILE "$<" *******************************
        UTLMSGMK.EXE  $(PRJUSERDIR)\$(PRJPROJECT)\$[r,$*].TXT  $(PRJUSERDIR)\$(PRJPROJECT)\$(OUTPUT_DIRECTORY)\$[r,$*].MSG  keep
        copy   UTLMSGMK.ITF $*.itf
        copy   UTLMSGMK.MIH $*.mih
        @del   UTLMSGMK.ITF
        @del   UTLMSGMK.MIH
        @del   UTLMSGMK.IMF


###      CommentBlock  /* (Monday 22/04/1996, 10:46:52, by Brett_Stas) */
###+--------------------------------------------------------------------------
###|##############################################################################
###|DO_SOM_COMPILE:
###|##############################################################################
###|        %do    AddBlankLines
###|        @echo *** DOING SOM COMPILE OF "$[r,$*].CSC" *******************
###|        %do     WorkOutWhere20ToolKitIs
###|        %setenv HPATH=$(TOOLKT20_DIR)\C\OS2H
###|        %setenv LIBPATH=$(TOOLKT20_DIR)\OS2LIB
###|        %setenv SMINCLUDE=.;$(TOOLKT20_DIR)\SC;
###|        %setenv SMTMP=.\$(OUTPUT_DIRECTORY)
###|        %setenv SMEMIT=ih;h;ph;def;psc;sc;c
###|        %setenv INCLUDE=.\$(OUTPUT_DIRECTORY);$(INCLUDE)
###|        -copy $[r,$*].C  $(OUTPUT_DIRECTORY) >nul 2>&1
###|        SC   -v -r -d$(OUTPUT_DIRECTORY) $[r,$*].CSC
###|        copy   $(OUTPUT_DIRECTORY)\$[r,$*].C
###|        -@del  $(OUTPUT_DIRECTORY)\$[r,$*].C
###+--------------------------------------------------------------------------
###                    /* (Monday 22/04/1996, 10:46:52, by Brett_Stas) */

###      CommentBlock  /* (Monday 22/04/1996, 11:20:16, by Brett_Stas) */
###+--------------------------------------------------------------------------
###|##############################################################################
###|WorkOutWhere20ToolKitIs:
###|##############################################################################
###|        %if %exists(D:\TOOLKT20\C\OS2H\OS2.H)
###|            @%set TOOLKT20_DIR = D:\TOOLKT20
###|        %else
###|            %if %exists(C:\TOOLKT20\C\OS2H\OS2.H)
###|                @%set TOOLKT20_DIR = C:\TOOLKT20
###|            %else
###|                @%set TOOLKT20_DIR = S:\TOOLKT20
###|            %endif
###|        %endif
###+--------------------------------------------------------------------------
###                    /* (Monday 22/04/1996, 11:20:16, by Brett_Stas) */


##############################################################################
DO_SOM_COMPILE_OF_IDL:
##############################################################################
        %do    AddBlankLines
        @echo *** DOING SOM COMPILE OF "$[r,$*].IDL" *** *** *************
        %setenv HPATH=P:\IBMCPP3.08\INCLUDE\OS2
        %setenv LIBPATH=P:\IBMCPP3.08\LIB
        %setenv SMINCLUDE=.;P:\IBMCPP3.08\INCLUDE\OS2;P:\IBMCPP3.08\INCLUDE\SOM;P:\IBMCPP3.08\INCLUDE;P:\IBMCPP3.08\som;P:\os2tk21\SC;
        %setenv SMTMP=.\$(OUTPUT_DIRECTORY)
        %setenv SMEMIT=ih;h;ph;def;psc;sc;c
        %setenv INCLUDE=.\$(OUTPUT_DIRECTORY);$(INCLUDE)
        %if %exists($[r,$*].C)
            -copy $[r,$*].C  $(OUTPUT_DIRECTORY) >nul 2>&1
            %if   %status
              @echo.
              @echo *** COPY of "$[r,$*].C" TO "$(OUTPUT_DIRECTORY)" DIRECTORY FAILED...
              @%exit 197
            %endif
        %endif
        -SC   -v -r -S60000 -d$(OUTPUT_DIRECTORY) $[r,$*].IDL
        %if   %status
              @echo.
              @echo *** SOM COMPILE FAILED...
              @del $(OUTPUT_DIRECTORY)\$[r,$*].IH
              @%exit 198
        %else
              -copy $(OUTPUT_DIRECTORY)\$[r,$*].C .
              %if    %status
                    @echo.
                    @echo *** COPY of "$[r,$*].C" TO SOURCE DIRECTORY FAILED.
                    @echo *** YOU HAVE PROBABLY GOT the file loaded in an editor etc...
                    @del $(OUTPUT_DIRECTORY)\$[r,$*].IH
                    @%exit 199
              %else
                    -@del  $(OUTPUT_DIRECTORY)\$[r,$*].C >nul 2>&1
              %endif
        %endif




##############################################################################
CREATE_PM_RES_FILE:
##############################################################################
        %do    AddBlankLines
        @echo *** MAKING PM RESOURCE FILE "$*.res" *******************
        RC -r  $<  $*.res


##############################################################################
C_COMPILE:
##############################################################################
        %do  AddBlankLines
        @echo *** COMPILING "$<" *******************************
        @%setenv INCLUDE=.\$(OUTPUT_DIRECTORY);$(INCLUDE)
        STDT $[r,$*].err "$(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$@ $<"


##############################################################################
MAKE_REXX_PROCEDURE:
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING  "$@" *******************************
        @%setenv INCLUDE=.\$(OUTPUT_DIRECTORY);$(INCLUDE)
        >-REXXIT.EXE  $<  $@  $(REXXIT_FLAGS)
        %do  DELETE_TARGET_ON_NOZERO_RC


##############################################################################
MAKE_DLL_IMPORT_LIBRARY:
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING LIBRARY "$@" *******************************
        %if %exists($@)
            del $@
        %endif
        >-IMPLIB.EXE $@  $<
        %do  DELETE_TARGET_ON_NOZERO_RC



##############################################################################
MAKE_LIBRARY:
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING LIBRARY "$@" *******************************
        %if %exists($@)
            del $@
        %endif
         @ copy < <
            $@
            y
            +$[s," &\n            +",$**]
            $*.lst
            ;
<  $*._CL >nul
       >-  $(LIBRARIAN) $(LIB_FLAGS)  @$*._CL
       %do  DELETE_TARGET_ON_NOZERO_RC



###      CommentBlock  /* (Monday 22/04/1996, 10:47:28, by Brett_Stas) */
###+--------------------------------------------------------------------------
###|##############################################################################
###|MAKE_EXE :
###|##############################################################################
###|        %do  AddBlankLines
###|        @echo *** MAKING EXECUTABLE "$@" *******************************
###|         @%set CRTIMEDLL = $[m,*.ob,$**]$[m,*.dil,$**]
###|         %if "$(CRTIMEDLL)" == ""
###|             @echo *** STATIC LINK WITH "C" runtime (and ANZ .LIBS's if used).
###|             @%set CRTIMEDLL =
###|         %else
###|             @echo *** DYNAMIC LINK WITH "C" runtime (and ANZ .DIL's if used).
###|             @%set CRTIMEDLL = /NOI
###|         %endif
###|         @ %set L_O       = $[m,*.obj,$**] $[m,*.ob,$**]
###|         @ %set L_L       = $[m,*.lib,$**] $[m,*.dil,$**]
###|         @ copy < <
###|            $(LINK_FLAGS) $(CRTIMEDLL) /BATCH /M +
###|            $[s,"+\n            ",$(L_O)]
###|            $*.exe
###|            $*.map
###|            $[s,"+\n            ",$(L_L)]
###|            $[m,*.def,$**];
###|<  $*._LE >nul
###|        @echo $(IBM_32BIT_LINKER) @$*._LE
###|        @type $*._LE
###|        @echo.
###|        @>-  $(IBM_32BIT_LINKER) @$*._LE
###|        %do  DELETE_TARGET_ON_NOZERO_RC
###|        %do  MAKE_SYM_FOR_KERNAL_DEBUGGER
###|        %do  ADD_RES_FILES_TO_EXE_OR_DLL
###|
###|
###|
###|##############################################################################
###|MAKE_DLL :
###|##############################################################################
###|        %do  AddBlankLines
###|        @echo *** MAKING DLL "$@" *******************************
###|
###|         ##### MAKE & LINK DUMMY DLL IF REQUIRED ##############################
###|         @%set CRTIMEDLL = $[m,*.ob,$**]$[m,*.dil,$**]
###|         %if "$(CRTIMEDLL)" == ""
###|                @echo *** MAKING A "NORMAL" DLL (everything statically linked).
###|#                @%set DUMMY_DLL_OBJECT  =
###|#                @%set CRTIMEDLL         =
###|#                @%set CRTIMEDLL         = /NOI
###|                @%set DUMMY_DLL_OBJECT  = $(OUTPUT_DIRECTORY)\DLLDUMY.OBJ
###|                @%set DUMMY_DLL_CSOURCE = .\DLLDUMY
###|                %if ! %exists($(DUMMY_DLL_OBJECT))
###|                        @echo *** NEED TO MAKE "$(DUMMY_DLL_OBJECT)" **************************
###|                        @echo /* No code. Compiled to supply DLL init code */ > $(DUMMY_DLL_CSOURCE).C
###|                        @%set COMPILE_FLAGS = /c /W3 /Re /Gm+ /Ge- /Gd-
###|                        @REM $(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT)  $(DUMMY_DLL_CSOURCE).C | teers $(DUMMY_DLL_CSOURCE).ERR
###|                        STDT.EXE $(DUMMY_DLL_CSOURCE).ERR "$(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT) $(DUMMY_DLL_CSOURCE).C"
###|                        @del $(DUMMY_DLL_CSOURCE).C
###|                %endif
###|         %else
###|                @echo *** MAKING A "ANZ" utility DLL (C-runtime dynamically linked as well).
###|                @%set CRTIMEDLL         = /NOI
###|                @%set DUMMY_DLL_OBJECT  = $(OUTPUT_DIRECTORY)\DLLDUMY.OB
###|                @%set DUMMY_DLL_CSOURCE = .\DLLDUMY
###|                %if ! %exists($(DUMMY_DLL_OBJECT))
###|                        @echo *** NEED TO MAKE "$(DUMMY_DLL_OBJECT)" **************************
###|                        @echo /* No code. Compiled to supply DLL init code */ > $(DUMMY_DLL_CSOURCE).C
###|                        @%set COMPILE_FLAGS = /c /W3 /Re /Gm+ /Ge- /Gd+
###|                        @REM $(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT)  $(DUMMY_DLL_CSOURCE).C | teers $(DUMMY_DLL_CSOURCE).ERR
###|                        STDT.EXE $(DUMMY_DLL_CSOURCE).ERR "$(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT) $(DUMMY_DLL_CSOURCE).C"
###|                        @del $(DUMMY_DLL_CSOURCE).C
###|                %endif
###|         %endif
###|
###|         @ %set L_O       = $[m,*.obj,$**] $[m,*.ob,$**] $(DUMMY_DLL_OBJECT)
###|         @ %set L_L       = $[m,*.lib,$**] $[m,*.dil,$**]
###|         @ copy < <
###|            $(LINK_FLAGS) $(CRTIMEDLL) /BATCH /M  +
###|            $[s,"+\n            ",$(L_O)]
###|            $*.dll
###|            $*.map
###|            $[s,"+\n            ",$(L_L)]
###|            $[m,*.def,$**];
###|<  $*._LD >nul
###|        @echo $(IBM_32BIT_LINKER) @$*._LD
###|        @type $*._LD
###|        @echo.
###|        @>-  $(IBM_32BIT_LINKER) @$*._LD
###|        %do  DELETE_TARGET_ON_NOZERO_RC
###|        %do  MAKE_SYM_FOR_KERNAL_DEBUGGER
###|        %do  ADD_RES_FILES_TO_EXE_OR_DLL
###+--------------------------------------------------------------------------
###                    /* (Monday 22/04/1996, 10:47:28, by Brett_Stas) */


##############################################################################
MAKE_DLL:
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING DLL "$@" *** *** *************************

         ##### MAKE & LINK DUMMY DLL IF REQUIRED ##############################
         @%set CRTIMEDLL = $[m,*.ob,$**]$[m,*.dil,$**]
         %if "$(CRTIMEDLL)" == ""
                @echo *** MAKING A "NORMAL" DLL (everything statically linked).
#               @%set DUMMY_DLL_OBJECT  =
#               @%set CRTIMEDLL         =
#               @%set CRTIMEDLL         = /NOI
                @%set DUMMY_DLL_OBJECT  = $(OUTPUT_DIRECTORY)\DLLDUMY.OBJ
                @%set DUMMY_DLL_CSOURCE = .\DLLDUMY
                %if ! %exists($(DUMMY_DLL_OBJECT))
                        @echo *** NEED TO MAKE "$(DUMMY_DLL_OBJECT)" **************************
                        @echo /* No code. Compiled to supply DLL init code */ > $(DUMMY_DLL_CSOURCE).C
                        @%set COMPILE_FLAGS = /c /W3 /Re /Gm+ /Ge- /Gd-
                        @REM $(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT)  $(DUMMY_DLL_CSOURCE).C | teers $(DUMMY_DLL_CSOURCE).ERR
                        STDT.EXE $(DUMMY_DLL_CSOURCE).ERR "$(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT) $(DUMMY_DLL_CSOURCE).C"
                        @del $(DUMMY_DLL_CSOURCE).C
                %endif
         %else
                @echo *** MAKING A "ANZ" utility DLL (C-runtime dynamically linked as well).
                @%set CRTIMEDLL         = /NOI
                @%set DUMMY_DLL_OBJECT  = $(OUTPUT_DIRECTORY)\DLLDUMY.OB
                @%set DUMMY_DLL_CSOURCE = .\DLLDUMY
                %if ! %exists($(DUMMY_DLL_OBJECT))
                        @echo *** NEED TO MAKE "$(DUMMY_DLL_OBJECT)" *** *** ********************
                        @echo /* No code. Compiled to supply DLL init code */ > $(DUMMY_DLL_CSOURCE).C
                        @%set COMPILE_FLAGS = /c /W3 /Re /Gm+ /Ge- /Gd+
                        @REM $(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT)  $(DUMMY_DLL_CSOURCE).C | teers $(DUMMY_DLL_CSOURCE).ERR
                        STDT.EXE $(DUMMY_DLL_CSOURCE).ERR "$(IBM_C_COMPILER) $(COMPILE_FLAGS) /Fo$(DUMMY_DLL_OBJECT) $(DUMMY_DLL_CSOURCE).C"
                        @del $(DUMMY_DLL_CSOURCE).C
                %endif
         %endif

         @ %set L_O       = $[m,*.obj,$**] $[m,*.ob,$**] $(DUMMY_DLL_OBJECT)
         @ %set L_L       = $[m,*.lib,$**] $[m,*.dil,$**]
         @ copy < <
            $(LINK_FLAGS) $(CRTIMEDLL) /M +
            $[s,"+\n            ",$(L_O)]
            $*.dll
            $*.map
            $[s,"+\n            ",$(L_L)]
            $[m,*.def,$**];
<  $*._LD >nul
        @echo ILINK /NOFREE @$*._LD
        @type $*._LD
        @echo.
        @>-  ILINK /NOFREE @$*._LD
        %do  DELETE_TARGET_ON_NOZERO_RC
        %do  MAKE_SYM_FOR_KERNAL_DEBUGGER
        %do  ADD_RES_FILES_TO_EXE_OR_DLL





##############################################################################
MAKE_EXE :
##############################################################################
        %do  AddBlankLines
        @echo *** MAKING EXECUTABLE "$@" *******************************
         @%set CRTIMEDLL = $[m,*.ob,$**]$[m,*.dil,$**]
         %if "$(CRTIMEDLL)" == ""
             @echo *** STATIC LINK WITH "C" runtime (and ANZ .LIBS's if used).
             @%set CRTIMEDLL =
         %else
             @echo *** DYNAMIC LINK WITH "C" runtime (and ANZ .DIL's if used).
             @%set CRTIMEDLL = /NOI
         %endif
         @ %set L_O       = $[m,*.obj,$**] $[m,*.ob,$**]
         @ %set L_L       = $[m,*.lib,$**] $[m,*.dil,$**]
         @ copy < <
            $(LINK_FLAGS) $(CRTIMEDLL)+
            $[s,"+\n            ",$(L_O)],
            $*.exe,
            $*.map,
            $[s,"+\n            ",$(L_L)],
            $[m,*.def,$**]
<  $*._LE >nul
        @echo ILINK /NOFREE @$*._LE
        @type $*._LE
        @echo.
        @>-  ILINK /NOFREE @$*._LE
        %do  DELETE_TARGET_ON_NOZERO_RC
        %do  MAKE_SYM_FOR_KERNAL_DEBUGGER
        %do  ADD_RES_FILES_TO_EXE_OR_DLL






##############################################################################
ADD_RES_FILES_TO_EXE_OR_DLL :
#
#  Note that we need to do the 2 eautil commands because of a bug in the
#  resource compiler where EAs in the file are lost.  This does currently
#  matter, for example HWPW.EXE does care (security check).
##############################################################################
        @ %set ADD_1_RES = $[m,*.res,$**]
        %foreach RES_FILE in $(ADD_1_RES)
                 @echo ***
                 @echo *** ADDING "$(RES_FILE)" FILES to "$@" *******************************
                 >-eautil $@  $*.EA /S /R /P
                 %do  DELETE_TARGET_ON_NOZERO_RC
                 -RC  $(RES_FILE) $@
                 %do  DELETE_TARGET_ON_NOZERO_RC
                 >-eautil $@  $*.EA /J /M
                 %do  DELETE_TARGET_ON_NOZERO_RC
        %endfor


##############################################################################
MAKE_SYM_FOR_KERNAL_DEBUGGER :
##############################################################################
        @echo ***
        @echo *** NOT MAKING KERNAL DEBUGGER SYM FILE "$*.SYM" (pgm sometimes traps - 21/4/95)
        @echo ***
###      CommentBlock  /* (Friday 21/04/1995, 15:43:47, by Dennis_Bareis) */
###+--------------------------------------------------------------------------
###|        @echo *** MAKING KERNAL DEBUGGER SYM FILE "$*.SYM" ******************
###|        @%cd $(OUTPUT_DIRECTORY)
###|        @mapsym $[r,$*].map
###|        @%cd ..
###+--------------------------------------------------------------------------
###                    /* (Friday 21/04/1995, 15:43:47, by Dennis_Bareis) */




##############################################################################
DELETE_TARGET_ON_NOZERO_RC :
##############################################################################
        %if %status
            %if %exists($@)
                @echo *** DELETING the target ($@) due to nonzero RC.
                @ del $@
            %else
                @echo *** NO TARGET ($@) to delete due to nonzero RC.
            %endif
            @ %exit 99
        %endif




##############################################################################
AddBlankLines :
##############################################################################
        @echo.
        @echo.
