#*---------------------------------------------------------------------------+
#
#     MODULE NAME:   PRJEXPRT.MAK
#
#         $Author:   Dennis_Bareis  $
#                    Andreas Buchinger  2009-2024
#       $Revision:   1.0  $
#           $Date:   22 Jul 1996 11:13:54  $
#        $Logfile:   Q:/PVCSDATA/SUPPORT/SUPPORT/PRJEXPRT.MAV  $
#
#     DESCRIPTION:   This Include file is included into any make file which
#                    wishes to do exports.
#
#                    To use the "calling" make file includes one or more
#                    pairs of lines similar to the following:
#
#                      +---------------------------------------------+
#                      |EXPORT_LIST =  EXPORT OUT V:\SUE 1.EXE 1.MSG |
#                      |.INCLUDE SUEEXPRT.MAK                        |
#                      +---------------------------------------------+
#
#                    The "EXPORT_LIST" definition must include at least 4
#                    parameters as follows:
#
#                       (1)  The name of the export target.  This when used
#                            as a target (for example using -f flag) will
#                            cause the exporting to occur.
#
#                       (2)  The name of the source directory, in the example
#                            above the "OUT" directory is used.
#
#                       (3)  The name of the destination directory, of course
#                            you may not wish to hard code it as shown here.
#
#                       (4+) A complete list of files (without path) which
#                            are to be exported.
#
#                      Note that if the root directory is either the source or
#                      the destination it should be specified as "?:" where '?'
#                      represents the drive.
#
#                      A good spot of these export lines is at the end of
#                      the makefile so that they don't become the default
#                      target!
#---------------------------------------------------------------------------*/

%if %defined(EXPORT_LIST)                       #List which defines what is being exported to where.
ExportMode        = GET_1ST
ExportTarget      = TargetUnknown
ExportSource      = SourceUnknown
ExportDestination = DestinationUnknown
%foreach Item in $(EXPORT_LIST)
%if $(ExportMode) = GET_1ST
ExportMode    = GET_2ND
ExportTarget  = $(Item)
%else
%if $(ExportMode) = GET_2ND
ExportSource  = $(Item)
ExportMode    = GET_3RD
%else
%if $(ExportMode) = GET_3RD
ExportDestination = $(Item)
ExportMode        = GET_REST
%else
%if %defined(PRJEXPORT)                          #Env Var exists if exports wanted.
$(ExportTarget)::  $(ExportDestination)\$(Item)
$(ExportDestination)\$(Item): $(ExportSource)\$(Item)
#####   @echo *** EXPORTING: $[r,$<].$[e,$<]  to directory  $[d,$@]
        @echo *** EXPORTING: $[u,$<]  to directory  $[u,$[d,$@]]
        @copy $< $@ >nul
%endif
%endif
%endif
%endif
%endfor
%endif




###############################################################################
### Tried to do something smarter than the above, see below, almost works $#@ #
###############################################################################

###      CommentBlock  /* (Monday the 18/01/1993, 10:27:42) */
###+--------------------------------------------------------------------------
###|EXPORT:: U:\SUE\SUPPORT\TMP PROD state.rst TEST.MAK SUE_DB.MA_
###|         @%echo *** DEBUG: DO EXPORT_FILES
###|         %do   EXPORT_FILES
###|
###|##############################################################################
###|EXPORT_1_FILE:
###|##############################################################################
###| %foreach xItem in $(Item)
###| @ %set Fred = Dummy$(ExportDestination)Dummy
###|       @%echo *** DEBUG *** EXPORT::   $(ExportDestination)\$(xItem)
###|       @%echo *** DEBUG ***  $(ExportDestination)\$(xItem): $(ExportSource)\$(xItem)
###|DOIT::   $(ExportDestination)\$(xItem)
###|$(ExportDestination)\$(xItem): $(ExportSource)\$(xItem)
###|               copy $(ExportSource)\$(xItem)  $(ExportDestination)\$(xItem)
###| %endfor
###|
###|##############################################################################
###|EXPORT_FILES:
###|##############################################################################
###|   @ %set ExportMode        = GET_1ST
###|   @ %set ExportSource      = SourceUnknown
###|   @ %set ExportDestination = DestinationUnknown
###|## -@del _Tmp__.MAK  >nul 2>&1
###|   %foreach Item in $**
###|       %if $(ExportMode) = GET_1ST
###|           @ %set ExportSource  = $(Item)
###|           @ %set ExportMode    = GET_2ND
###|       %else
###|           %if $(ExportMode) = GET_2ND
###|               @ %set ExportDestination = $(Item)
###|               @ %set ExportMode        = GET_REST
###|           %else
###|              @%echo *** DEBUG: MODE REST for = $(Item)
###|              %do EXPORT_1_FILE
###|           %endif
###|       %endif
###|   %endfor
###|## pmake -f _Tmp__.MAK xEXPORT
###|
###|
###|##############################################################################
###|##EXPORT_1_FILE:
###|##############################################################################
###|##       @%echo *** DEBUG *** EXPORT::   $(ExportDestination)\$(Item)
###|##       @%echo *** DEBUG ***  $(ExportDestination)\$(Item): $(ExportSource)\$(Item)
###|## echo xEXPORT::   $(ExportDestination)\$(Item) >> _Tmp__.MAK
###|## echo $(ExportDestination)\$(Item): $(ExportSource)\$(Item) >> _Tmp__.MAK
###|## echo               copy $(ExportSource)\$(Item)  $(ExportDestination)\$(Item) >> _Tmp__.MAK
###+--------------------------------------------------------------------------
###                    /* (Monday the 18/01/1993, 10:27:42) */
