#*---------------------------------------------------------------------------+
#
#     MODULE NAME:   PRJVAC30.INC
#
#         $Author:   Dennis_Bareis  $
#                    Andreas Buchinger  2009-2024
#       $Revision:   1.5  $
#           $Date:   12 Aug 1997 13:57:32  $
#        $Logfile:   Q:/PVCSDATA/SUPPORT/support/prjvac30.inv  $
#
#     DESCRIPTION:   Include file (not used directly) in user make files
#                    but is included by PrjVac30.MAK, the contents
#                    are variables which can be overriden by the user in
#                    very limited & unusual circumstances.
#
#                    To override:
#
#                       (1) Included "PrjVac30.MAK"
#                       (2) Redefine as many of the following as required.
#
#            NOTE:   While the facility is there for overriding the flags in
#                    this file in general there are better ways to do so.  For
#                    example if compiling to an "OBJ" file you could update
#                    "C_FLAGS_OBJ" instead as any option included there will
#                    also override the default without requiring you to do a
#                    possibly "massive" redefinition of base flags.  As an
#                    example if you wished to compile code as single threaded
#                    instead of the default multi-threaded you would include
#                    /Gm- in "C_FLAGS_OBJ"
#
#
#           /Ol+     does improve size slightly but in current version causes
#                    too many files to fail to compile, for example UTLTAIL.C,
#                    UTLCONF.C
#*---------------------------------------------------------------------------+



#############################################################################
#### The following can be overriden by "caller" #############################
#############################################################################
_ICCFLG_OPTIMISE         = -Mp -O+ -Oc+ -G4
_ICCFLG_WARNING_LEVEL    = -N30 -W3ProIniObsOrdRetCnd-
_C_COMPILE_FLAGS_OBJ     = /Q /c $(ICCFLG_MULTI_THREAD) $(_ICCFLG_OPTIMISE) $(ICCFLG_ALLOW_SLASHBY2) /Gd- $(_ICCFLG_WARNING_LEVEL) $(ICCFLG_COMPILE_AS_C)
_C_COMPILE_FLAGS_OB      = /Q /c $(ICCFLG_MULTI_THREAD) $(_ICCFLG_OPTIMISE) $(ICCFLG_ALLOW_SLASHBY2) /Gd+ $(_ICCFLG_WARNING_LEVEL) $(ICCFLG_COMPILE_AS_C)
_CPP_COMPILE_FLAGS_OBJ   = /Q /c $(ICCFLG_MULTI_THREAD) $(_ICCFLG_OPTIMISE) $(ICCFLG_ALLOW_SLASHBY2) /Gd- $(_ICCFLG_WARNING_LEVEL) $(ICCFLG_COMPILE_AS_CPP) -Ft$(CppTemplateDirectory)
_CPP_COMPILE_FLAGS_OB    = /Q /c $(ICCFLG_MULTI_THREAD) $(_ICCFLG_OPTIMISE) $(ICCFLG_ALLOW_SLASHBY2) /Gd+ $(_ICCFLG_WARNING_LEVEL) $(ICCFLG_COMPILE_AS_CPP) -Ft$(CppTemplateDirectory)
_APP_COMPILE_FLAGS_OBJ   = /Q /c $(ICCFLG_MULTI_THREAD) $(_ICCFLG_OPTIMISE) $(ICCFLG_ALLOW_SLASHBY2) /Gd- $(_ICCFLG_WARNING_LEVEL) $(ICCFLG_COMPILE_AS_CPP) -Ft$(CppTemplateDirectory)
_APP_COMPILE_FLAGS_OB    = /Q /c $(ICCFLG_MULTI_THREAD) $(_ICCFLG_OPTIMISE) $(ICCFLG_ALLOW_SLASHBY2) /Gd+ $(_ICCFLG_WARNING_LEVEL) $(ICCFLG_COMPILE_AS_CPP) -Ft$(CppTemplateDirectory)
_COMPILE_FLAGS_DUMMY_OBJ = /Q /c $(ICCFLG_MULTI_THREAD) /Ge- /Gd- /W1
_COMPILE_FLAGS_DUMMY_OB  = /Q /c $(ICCFLG_MULTI_THREAD) /Ge- /Gd+ /W1
_COMPILE_DEBUG           = /O-
#_LINK_FLAGS_EXE          = /Noe /Map /NoLogo /Align:2 /ExePack:1 /BASE:0x10000 /Stack:0x80000 /PM:VIO   # 20231229 remove some options
_LINK_FLAGS_EXE          =  /Map /NoLogo /PM:VIO
#_LINK_FLAGS_DLL          = /Noe /Map /NoLogo /Align:2 /ExePack:1 /DLL /Stack:0x80000   # 20231229 remove some options
_LINK_FLAGS_DLL          =  /Map /NoLogo /DLL
_LIB_FLAGS               = /NoLogo /NoIgnoreCase /NoBackup
#_LINK_DEBUG              = /DbgPack	20231229 remove pack symbols
_LINK_DEBUG              =
_IPFC_INF_FLAGS          = /S /INF
_IPFC_HLP_FLAGS          = /S
_ADD_RESOURCE_2EXE_FLAGS = -n -x1
_CREATE_RESOURCE_FLAGS   = -n -x1 -r
_MAPSYM_OPTIONS          = /N /L
_LXLITE_FLAGS            = /B- /CS /YDA /YXA /YNA
_LXLITE_ENABLED          = YES
#_MAPSYM_ENABLED          = YES
_IPFC_RUNTIME_MSG_FILE   = $(CPPMAIN)\HELP\DDE4.MSG
_LIBRARIAN               = ILib.EXE
_IBM_C_COMPILER          = ICC.EXE
_IBM_32BIT_LINKER        = ILink.EXE /NOFREE
_IBM_IMPLIB              = ImpLib.EXE /NOLOGO
_IBM_RESOURCE_COMPILER   = RC.EXE
_IBM_MSG_BINDER          = MsgBind.exe
_IBM_MAPSYM              = MAPSYM.EXE
_IBM_IPF_COMPILER        = IPFC.EXE
_IBM_IPF_PREPROCESSOR    = support\IPFCPREP.EXE
_ANZ_IPF_PREPROCESSOR    = support\SRCHREPL.EXE
_ANZ_HTML_PREPROCESSOR   = PPWIZARD.CMD
_ANZ_MSG_COMPILER        = support\UTLMSGMK.EXE
_DB_BETTER_TEE           = support\STDT.EXE
_OS2_EAUTIL              = EAUTIL.EXE
_LXITE                   = LXLITE.EXE

MX = mapxqs.exe
MXFLAGS = -v

#############################################################################
###[ How is .X -> .CMD done? ]##############################################
#############################################################################
_USE_REXXIT_4_X2CMD      = YES
_ANZ_REXX_PREPROCESSOR   = support\REXXIT.EXE
_PPWIZARD_PREPROCESSOR   = PPWIZARD.CMD
_PPWIZARD_2REXX_FLAGS    =


#############################################################################
#### The following can be used by "caller" ##################################
#############################################################################
_C_AND_CPP_SHOW_PREPROCESSED_OUTPUT = /Pc+
_C_AND_CPP_GENERATE_ASSEMBLER       = /Fa$(OutputDirectory)



#############################################################################
#### Special Handling for Visual Builder's .APP files #######################
#############################################################################
_AddPvHandlerToAppModules = Yes                 #Set to 'No' to prevent PV handler being added.
